C Sedtrans05 - a sediment transport model
C
C Copyright (C) 2005 Urs Neumeier, Christian Ferrarin, Carl Amos
C and Georg Umgiesser.
C Sedtrans05 was developed at the ISMAR-CNR in Venice and the
C University of Southampton.
C Previous versions of Sedtrans (1992 and 1996) were developed at
C the Geological Survey of Canada, Bedford Institute of Oceanography.
C
C This program is free software; you can redistribute it and/or modify
C it under the terms of the GNU General Public License as published by
C the Free Software Foundation; either version 3 of the License, or
C (at your option) any later version. See file "licence.txt" in the
C Sedtrans05 directory for the full licence text, which can also be
C found at http://www.gnu.org/licenses/
C
C This program is distributed in the hope that it will be useful,
C but WITHOUT ANY WARRANTY; without even the implied warranty of
C MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C GNU General Public License for more details.
C
C ======================================================================
C ======================================================================
C SUBROUTINE BEDFORM
C
C  This subroutine predicts the expected type of bedform for the given
C  flow conditions. The bedform type is only approximate for coarse and very
C  coarse sands since it is based on velocity measurements only. the limits
C  are from Amos (1990) and Li and Amos (1998). Ripple dimension is also
C  predicted for fine and medium sands.
C
C Li and Amos (1998) Continental Shelf Research, 18, 941-970
C Amos C.L. (1990) Modern sedimentary processes. In : Keen M.J. & Williams G.L.
C (eds.) Geology of the continental margin of Eastern Canada. Geological
C Survey of Canada, Geology of Canada, no. 2, p. 609-673.

      SUBROUTINE BEDFORM(U100,UA,UB,GD,FCW,RHOW,RHOS,VISC,IOPT1,
     @RHEIGHT,RLENGTH,USTCWS,USTCRB,USTCRS,USTUP,BEDTXT)

      IMPLICIT NONE
      INCLUDE "sed_param.h"

      DOUBLE PRECISION U100,UA,UB,GD,FCW,RHOW,RHOS,VISC,
     @RHEIGHT,RLENGTH,USTCWS,USTCRB,USTCRS,USTUP
      INTEGER IOPT1
      CHARACTER*80 BEDTXT(7)
      
      DOUBLE PRECISION VISK,S,SST,PSICR,PSIBF,RATIO,WSP,CSP,
     @PHI,RL,RH
      INTEGER N

      DO 11, N=1,6
         BEDTXT(N)=' '
11    CONTINUE
      N=0
      VISK = VISC/RHOW
      S = RHOS/RHOW
      SST = GD*((S-1d0)*G*GD)**0.5d0/(4d0*VISK)
      PSICR = (USTCRB**2)/((S-1d0)*G*GD)
      PSIBF = 1.8d0*(SST**0.6d0)*PSICR
      USTBF = (PSIBF*(S-1d0)*G*GD)**0.5d0
      IF (USTCS .EQ. 0) THEN
         RATIO=1
      ELSE
         RATIO=USTWS/USTCS
      ENDIF
C
C  INPUT VARIABLES:
C
C        U100 = CURRENT SPEED AT 1 M. ABOVE SEABED ( M/SEC)
C        UA = MEAN VELOCITY AT TOP OF THE WAVE BOUNDARY LAYER (M/SEC)
C        UB = MAXIMUM WAVE-INDUCED BOTTOM PARTICLE VELOCITY (M/SEC)
C        AB = EXCURSION LENGTH OF BOTTOM WAVE ORBIT (M)
C        FCW = BOTTOM (SKIN) FRICTION FACTOR
C        GD = SEDIMENT GRAIN SIZE (M)
C
C ********************************************************************
C SKIP THE BEDFORM SECTION IF SEDIMENTS ARE COHESIVE
      IF (IOPT1.EQ.7) THEN
         N=N+1
         WRITE (BEDTXT(N),1005)
1005  FORMAT('No bedform estimates for cohesive sediments ')
         RETURN
      ENDIF
C ********************************************************************
C
C SET UP FORMAT STATEMENTS
C

C WAVES ONLY
  20  FORMAT('Wave induced bedforms:')
  25  FORMAT('wave ripples')
  30  FORMAT('wave ripples or wave-induced (upper) flat bed')
  35  FORMAT('wave-induced (upper) flat bed')
C CURRENTS ONLY
  40  FORMAT('Current induced bedforms:')
  45  FORMAT('current ripples')
  55  FORMAT('flat bed (lower)')
  65  FORMAT('flat bed (lower) or 2-d megaripples')
  75  FORMAT('flat bed (lower) or 2-d megaripples or sand waves')
  85  FORMAT('2-D megaripples')
  95  FORMAT('2-D megaripples or sand waves')
 105  FORMAT('sand waves')
 115  FORMAT('sand waves or 3-d megaripples')
 125  FORMAT('3-D megaripples')
 135  FORMAT('flat bed (upper) and sand ribbons')
 145  FORMAT('upper flat bed and sediment in suspension')
C CURRENTS AND WAVES
 155  FORMAT('No transport')
C 156  FORMAT('No transport  flat bed')         ! useless FORMAT
 164  FORMAT('Bedforms unknown for co-directional mixed flow ',
     &'conditions but:')
 165  FORMAT('work by Amos et al (1987) shows that independent')
 166  FORMAT('wave and current bedforms may exist which would be:')
 167  FORMAT('bedform types predicted based on SIB data of ',
     &'Li and Amos (1998)')
 168  FORMAT('weak-transport ripples')
 169  FORMAT('break-off ripples')
 170  FORMAT('equilibrium ripples')
 171  FORMAT('current-dominated ripples')
 172  FORMAT('wave-current ripples')
 173  FORMAT('wave-dominated ripples')
 175  FORMAT('possible gravel ripples (e.g. .2 m high & 2 m long)')
 176  FORMAT('(see Forbes and Boyd (1987) for further detail)')
 185  FORMAT('bedform dimensions not yet available')
 265  FORMAT('bedforms unknown for orthogonal mixed flow conditions '
     &,/,'for other than very fine-medium sand but:')
C 266  FORMAT('work by Amos et al (1987) shows that independent',/,
C     &'wave and current bedforms exist which are:',/)   ! useless FORMAT
 405  FORMAT('Very coarse sand (Wentworth scale)')
 415  FORMAT('Coarse sand (Wentworth scale)')
 425  FORMAT('Medium sand (Wentworth scale)')
 435  FORMAT('Fine or very fine sand (Wentworth scale)')
 445  FORMAT('Silt or clay (Wentworth scale)')
 446  FORMAT('No bedform data available')
C
C GRANULE AND GRAVEL SIZES (WENTWORTH SCALE) UNDER ALL FLOW CONDITIONS
C
      IF (GD .GT. 0.002) THEN
         N=N+1
         WRITE (BEDTXT(N),175)
         N=N+1
         WRITE (BEDTXT(N),176)
         RETURN
      ENDIF
C
C  FOR CLAY OR SILT (WENTWORTH SCALE), BEDFORM WILL NOT BE PREDICTED
C
      IF (GD .LE. 0.000063) THEN
         N=N+1
         WRITE (BEDTXT(N),445)
         N=N+1
         WRITE (BEDTXT(N),446)
         RETURN
      ENDIF
C
C SINCE THE GRAIN SIZE CLASSIFICATION IS BASED ON THE WENTWORTH SCALE
C WHICH IS BASED ON PHI SIZES, THE PHI UNITS CAN BE USED TO DIRECT
C THIS PROGRAM.
C
C PHI IS THE NEXT HIGHEST PHI UNIT (IE VERY FINE SAND =4
C                                           FINE SAND =3
C                                         MEDIUM SAND =2
C                                         COARSE SAND =1
C                                    VERY COARSE SAND =0)
C
C WSP = WAVE SKIN-FRICTION SHIELD'S PARAMETER
C CSP = CURRENT SKIN-FRICTION SHIELD'S PARAMETER
C
      WSP=RHOW*FCW*UB*UB/(2d0*(RHOS-RHOW)*G*GD)
      CSP=RHOW*USTCS**2
      PHI=-DLOG(500.D0*GD)/DLOG(2.d0)  ! This is not phi, but phi+1 (but it work correctly)
C      CONV=4.D0/DLOG(0.0625D0)
C      PHI=CONV*DLOG(1000.D0*GD/2.D0)
      GOTO (1,2,3,4,5)INT(PHI+1)
C
 1    CONTINUE
C
C VERY COARSE SAND (WENTWORTH SCALE)
C
      N=N+1
      WRITE (BEDTXT(N),405)
      N=N+1
      WRITE (BEDTXT(N),185)
C
C --- FIRST, CHECK FOR COMBINED FLOW CONDITIONS
      IF (UB .NE. 0. .AND. UA .NE. 0.) THEN
         IF (PHIB*180/PII .LE. 45.)THEN
C CO-DIRECTIONAL WAVES AND CURRENTS
            N=N+1
            WRITE (BEDTXT(N),164)
            N=N+1
            WRITE (BEDTXT(N),165)
            N=N+1
            WRITE (BEDTXT(N),166)
         ELSE
C ORTHOGONAL WAVES AND CURRENTS
            N=N+1
            WRITE (BEDTXT(N),265)
            N=N+1
            WRITE (BEDTXT(N),165)
            N=N+1
            WRITE (BEDTXT(N),166)
         ENDIF
C PREDICT BEDFORM TYPES BASED ON THE RATIO OF WSP/CSP
         IF (RATIO .GE. 1) THEN
C WAVE-DOMINANT BEDFORMS
            N=N+1
            WRITE (BEDTXT(N),512)
            IF (UB .LT. 0.3) THEN
               N=N+1
               WRITE (BEDTXT(N),155)
            ELSEIF (UB .LT. 1.0) THEN
               N=N+1
               WRITE (BEDTXT(N),25)
            ELSEIF (UB .LT. 2.0) THEN
               N=N+1
               WRITE (BEDTXT(N),30)
            ELSE
               N=N+1
               WRITE (BEDTXT(N),35)
            ENDIF
         ELSE
C CURRENT-DOMINANT BEDFORMS
            N=N+1
            WRITE (BEDTXT(N),505)
            IF (U100 .LT. 0.4) THEN
               N=N+1
               WRITE (BEDTXT(N),155)
            ELSEIF (U100 .LE. 0.45) THEN
               N=N+1
               WRITE (BEDTXT(N),95)
            ELSEIF (U100 .LE. 0.5) THEN
               N=N+1
               WRITE (BEDTXT(N),75)
            ELSEIF (U100 .LE. 0.6) THEN
               N=N+1
               WRITE (BEDTXT(N),95)
            ELSEIF (U100 .LE. 1.0) THEN
               N=N+1
               WRITE (BEDTXT(N),105)
            ELSEIF (U100 .LE. 2.95) THEN
               N=N+1
               WRITE (BEDTXT(N),135)
            ELSE
               N=N+1
               WRITE (BEDTXT(N),145)
            ENDIF
         ENDIF
      ENDIF
C
C --- PURE WAVE CASE
      IF (UB .NE. 0.0 .AND. UA .EQ. 0) THEN
         N=N+1
         WRITE (BEDTXT(N),20)
         IF (UB .LT. 0.3) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (UB .LT. 1.0) THEN
            N=N+1
            WRITE (BEDTXT(N),25)
         ELSEIF (UB .LT. 2.0) THEN
            N=N+1
            WRITE (BEDTXT(N),30)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),35)
         ENDIF
      ENDIF
C
C --- PURE CURRENT CASE
      IF (UA .NE. 0.0 .AND. UB .EQ. 0) THEN
         N=N+1
         WRITE (BEDTXT(N),40)
         IF (U100 .LT. 0.4) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (U100 .LE. 0.45) THEN
            N=N+1
            WRITE (BEDTXT(N),95)
         ELSEIF (U100 .LE. 0.5) THEN
            N=N+1
            WRITE (BEDTXT(N),75)
         ELSEIF (U100 .LE. 0.6) THEN
            N=N+1
            WRITE (BEDTXT(N),95)
         ELSEIF (U100 .LE. 1.0) THEN
            N=N+1
            WRITE (BEDTXT(N),105)
         ELSEIF (U100 .LE. 2.95) THEN
            N=N+1
            WRITE (BEDTXT(N),135)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),145)
         ENDIF
      ENDIF
      RETURN
C
 2    CONTINUE
C
C COARSE SAND (WENTWORTH SCALE)
C
      N=N+1
      WRITE (BEDTXT(N),415)
      N=N+1
      WRITE (BEDTXT(N),185)
C --- FIRST, CHECK FOR COMBINED FLOW CONDITIONS
      IF(UB.NE.0. .AND. UA.NE.0.)THEN
         IF(PHIB*180/PII .LE. 45.)THEN
C CO-DIRECTIONAL WAVES AND CURRENTS
            N=N+1
            WRITE (BEDTXT(N),164)
            N=N+1
            WRITE (BEDTXT(N),165)
            N=N+1
            WRITE (BEDTXT(N),166)
         ELSE
C ORTHOGONAL WAVES AND CURRENTS
            N=N+1
            WRITE (BEDTXT(N),265)
            N=N+1
            WRITE (BEDTXT(N),165)
            N=N+1
            WRITE (BEDTXT(N),166)
         ENDIF
C PREDICT BEDFORM TYPES BASED ON THE RATIO OF WSP/CSP
         IF (RATIO .GE. 1) THEN
C WAVE-DOMINANT BEDFORMS
            N=N+1
            WRITE (BEDTXT(N),512)
            IF (UB .LT. 0.3) THEN
               N=N+1
               WRITE (BEDTXT(N),155)
            ELSEIF (UB .LT. 1.0) THEN
               N=N+1
               WRITE (BEDTXT(N),25)
            ELSEIF (UB .LT. 2.0) THEN
               N=N+1
               WRITE (BEDTXT(N),30)
            ELSE
               N=N+1
               WRITE (BEDTXT(N),35)
            ENDIF
         ELSE
C CURRENT-DOMINANT BEDFORMS
            N=N+1
            WRITE (BEDTXT(N),505)
            IF (U100 .LT. 0.25) THEN
               N=N+1
               WRITE (BEDTXT(N),155)
            ELSEIF (U100 .LT. 0.35) THEN
               N=N+1
               WRITE (BEDTXT(N),45)
            ELSEIF (U100 .LT. 0.4) THEN
               N=N+1
               WRITE (BEDTXT(N),55)
            ELSEIF (U100 .LT. 0.45) THEN
               N=N+1
               WRITE (BEDTXT(N),65)
            ELSEIF (U100 .LT. 0.5) THEN
               N=N+1
               WRITE (BEDTXT(N),85)
            ELSEIF (U100 .LT. 0.6) THEN
               N=N+1
               WRITE (BEDTXT(N),95)
            ELSEIF (U100 .LT. 1.0) THEN
               N=N+1
               WRITE (BEDTXT(N),115)
            ELSEIF (U100 .LT. 1.5) THEN
               N=N+1
               WRITE (BEDTXT(N),125)
            ELSEIF (U100 .LT. 2.4) THEN
               N=N+1
               WRITE (BEDTXT(N),135)
            ELSE
               N=N+1
               WRITE (BEDTXT(N),145)
            ENDIF
         ENDIF
      ENDIF
C
C --- PURE WAVE CASE
      IF (UB .NE. 0.0 .AND. UA .EQ. 0) THEN
         N=N+1
         WRITE (BEDTXT(N),20)
         IF (UB .LT. 0.2) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (UB .LT. 0.9) THEN
            N=N+1
            WRITE (BEDTXT(N),25)
         ELSEIF (UB .LT. 1.25) THEN
            N=N+1
            WRITE (BEDTXT(N),30)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),35)
         ENDIF
      ENDIF
C
C --- PURE CURRENT CASE
      IF (UA .NE. 0.0 .AND. UB .EQ. 0) THEN
         N=N+1
         WRITE (BEDTXT(N),40)
         IF (U100 .LT. 0.25) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (U100 .LT. 0.35) THEN
            N=N+1
            WRITE (BEDTXT(N),45)
         ELSEIF (U100 .LT. 0.4) THEN
            N=N+1
            WRITE (BEDTXT(N),55)
         ELSEIF (U100 .LT. 0.45) THEN
            N=N+1
            WRITE (BEDTXT(N),65)
         ELSEIF (U100 .LT. 0.5) THEN
            N=N+1
            WRITE (BEDTXT(N),85)
         ELSEIF (U100 .LT. 0.6) THEN
            N=N+1
            WRITE (BEDTXT(N),95)
         ELSEIF (U100 .LT. 1.0) THEN
            N=N+1
            WRITE (BEDTXT(N),115)
         ELSEIF (U100 .LT. 1.5) THEN
            N=N+1
            WRITE (BEDTXT(N),125)
         ELSEIF (U100 .LT. 2.4) THEN
            N=N+1
            WRITE (BEDTXT(N),135)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),145)
         ENDIF
      ENDIF
      RETURN
C

 3    CONTINUE
C
C  MEDIUM SAND (WENTWORTH SCALE)
C
      N=N+1
      WRITE (BEDTXT(N),425)
C
C  FIRST, CHECK FOR COMBINED FLOW CONDITIONS. IF NOT, GO TO 31
      IF(UB.EQ.0. .OR. UA.EQ.0.) GOTO 31
C GO TO 10 FOR BEDFORM TYPES AND DIMENSION UNDER COMBINED FLOWS
      GOTO 10

 4    CONTINUE
C
C FINE SAND (WENTWORTH SCALE)
C
      N=N+1
      WRITE (BEDTXT(N),435)
C
C --- FIRST, CHECK FOR COMBINED FLOW CONDITIONS. IF NOT, GO TO 41.
      IF(UB.EQ.0. .OR. UA.EQ.0.) GOTO 41
C GO TO 10 FOR BEDFORM TYPES AND DIMENSION UNDER COMBINED FLOWS
      GOTO 10

 5    CONTINUE
C
C VERY FINE SAND (WENTWORTH SCALE)
C
      N=N+1
      WRITE (BEDTXT(N),435)
C
C --- FIRST, CHECK FOR COMBINED FLOW CONDITIONS. IF NOT, GO TO 41.
      IF(UB.EQ.0. .OR. UA.EQ.0.) GOTO 41
C CONTINUE FOR BEDFORM TYPES AND DIMENSION UNDER COMBINED FLOWS

 10   CONTINUE
C PREDICT BEDFORM TYPES AND DIMENSIONS UNDER COMBINED FLOWS BASED ON
C LI AND AMOS (IN REVIEW)
      N=N+1
      WRITE (BEDTXT(N),167)
C NO TRANSPORT IF RIPPLE-ENHANCED SHEAR VELOCITY < CRITICAL SHEAR VELOICTY
      IF (USTCWSE .LT. USTCRB) THEN
         N=N+1
         WRITE (BEDTXT(N),155)
         GOTO 1007
      ENDIF
C UPPER FLAT BED PREDICTED IF BEDLOAD-ENHANCED UST > SHEET-FLOW THRESHOLD
      IF (USTCWSB .GE. USTUP) THEN
         N=N+1
         WRITE (BEDTXT(N),145)
         GOTO 1007
      ENDIF
C WEAK-TRANSPORT RIPPLES
      IF (USTCWSE .GE. USTCRB .AND. USTCWS .LT. USTCRB) THEN
         N=N+1
         WRITE (BEDTXT(N),168)
         GOTO 1007
      ENDIF
C BREAK-OFF RIPPLES
      IF (USTCWSB  .GE. USTBF) THEN
         N=N+1
         WRITE (BEDTXT(N),169)
C EQUILIBRIUM RIPPLES
      ELSE
         N=N+1
         WRITE (BEDTXT(N),170)
      ENDIF
C PREDICT RIPPLE TYPES FOR EQUILIBRIUM AND BREAK-OFF RIPPLES
      IF (RATIO .LT. 0.75) THEN
         N=N+1
         WRITE (BEDTXT(N),171)
      ELSEIF (RATIO .LE. 1.25) THEN
         N=N+1
         WRITE (BEDTXT(N),172)
      ELSE
         N=N+1
         WRITE (BEDTXT(N),173)
      ENDIF
C MOVE TO 1007 FOR PRINTING OUT COMBINED-FLOW RIPPLE HEIGHT AND LENGTH
C OBTAINED FROM FRICFAC.FOR SUBROUTINE
      GOTO 1007
C
 31   CONTINUE
C PURE WAVE CASE, MEDIUM SAND
      IF (UB .NE. 0.0) THEN
         N=N+1
         WRITE (BEDTXT(N),20)
         IF (UB .LT. 0.13) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (UB .LT. 0.8) THEN
            N=N+1
            WRITE (BEDTXT(N),25)
         ELSEIF (UB .LT. 1.0) THEN
            N=N+1
            WRITE (BEDTXT(N),30)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),35)
         ENDIF
C FOR WAVE RIPPLE HEIGHT AND LENGTH PREDICTION, MOVE TO 43
         GOTO 43
      ENDIF
C  PURE CURRENT CASE, MEDIUM SAND
      IF (UA .NE. 0.0) THEN
         N=N+1
         WRITE (BEDTXT(N),40)
         IF (U100 .LT. 0.2) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (U100 .LT. 0.5) THEN
            N=N+1
            WRITE (BEDTXT(N),45)
         ELSEIF (U100 .LT. 0.6) THEN
            N=N+1
            WRITE (BEDTXT(N),85)
         ELSEIF (U100 .LT. 1.0) THEN
            N=N+1
            WRITE (BEDTXT(N),115)
         ELSEIF (U100 .LT. 1.5) THEN
            N=N+1
            WRITE (BEDTXT(N),125)
         ELSEIF (U100 .LT. 1.7) THEN
            N=N+1
            WRITE (BEDTXT(N),135)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),145)
         ENDIF
C FOR CURRENT RIPPLE HEIGHT AND LENGTH PREDICTION, MOVE TO 44
         GOTO 44
      ENDIF
      RETURN
C
C PURE WAVE CASE, FINE AND VERY-FINE SAND
 41   IF (UB .NE. 0.0) THEN
         IF (UB .LT. 0.1) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (UB .LT. 0.7) THEN
            N=N+1
            WRITE (BEDTXT(N),25)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),35)
         ENDIF
C FOR WAVE RIPPLE HEIGHT AND LENGTH PREDICTION, GO TO 43
         GOTO 43
      ENDIF
C  PURE CURRENT CASE, FINE AND VERY-FINE SAND
      IF (UB .EQ. 0.0) THEN
         IF (U100 .LT. 0.13) THEN
            N=N+1
            WRITE (BEDTXT(N),155)
         ELSEIF (U100 .LT. 0.6) THEN
            N=N+1
            WRITE (BEDTXT(N),45)
         ELSEIF (U100 .LT. 0.85) THEN
            N=N+1
            WRITE (BEDTXT(N),135)
         ELSE
            N=N+1
            WRITE (BEDTXT(N),145)
         ENDIF
C FOR CURRENT RIPPLE HEIGHT AND LENGTH PREDICTION, GO TO 44
         GOTO 44
      ENDIF
C
C --- PREDICTING RIPPLE DIMENSION FOR WAVE-INDUCED RIPPLES
C FIRST CHECK FOR POORLY-DEVELOPED RIPPLES
 43   IF(CSP.LT.0.04 .AND. (WSP+CSP).GE.0.04 .AND.
     &(WSP+CSP).LT.0.18 )THEN
         N=N+1
         WRITE (BEDTXT(N),513)
         N=N+1
         WRITE (BEDTXT(N),514)
      ENDIF
C DIMENSIONS OF WAVE-INDUCED RIPPLES FROM BOYD ET AL. (1988) AND ALLEN (1970)
C HAVE BEEN GIVEN IN FRICFAC SUBROUTINE AND ARE ASSIGNED TO RL AND RH HERE
      RL=RLENGTH
      RH=RHEIGHT
      N=N+1
      WRITE (BEDTXT(N),605)RL
      N=N+1
      WRITE (BEDTXT(N),606)RH
      RETURN
C
C --- PREDICTING RIPPLE DIMENSION FOR CURRENT-INCUCED RIPPLES
C DIMENSIONS OF CURRENT RIPPLES AFTER YALIN (1964) AND ALLEN (1970) ARE DONE
C IN FRICFAC AND ARE MERELY ASSINGED TO RL AND RH HERE
 44   CONTINUE
      RL=RLENGTH
      RH=RHEIGHT
      N=N+1
      WRITE (BEDTXT(N),610)RL
      N=N+1
      WRITE (BEDTXT(N),611)RH
      RETURN
C
 505  FORMAT('Current-dominated bedforms')
 512  FORMAT('Wave-dominated bedforms')
 513  FORMAT('Poorly developed ripples may exist depending on')
 514  FORMAT('local bioturbation rates and broadness of wave spectrum')
 605  FORMAT('wave ripple length from Boyd et al (1988) =',F6.3,' m')
 606  FORMAT('wave ripple height from Allen (1970)      =',F6.3,' m')
 610  FORMAT('current ripple length from Yalin (1964) =',F6.3,' m')
 611  FORMAT('ripple height from Allen (1970)         =',F6.3,' m')
 620  FORMAT('ripple height= ',F7.3,' m   ripple length= ',F7.3,' m')

C PRINT OUT COMBINED-FLOW RIPPLE HEIGHT AND LENGTH OBTAINED FROM
C FRICFAC.FOR SUBROUTINE
1007  N=N+1
      WRITE (BEDTXT(N),620) RHEIGHT,RLENGTH

      END    ! end of routine BEDFORM

