C****************************************************************************
C
C              SEDTRANS05:    A SEDIMENT TRANSPORT MODEL FOR
C                           CONTINENTAL SHELVES AND ESTUARIES
C
C****************************************************************************
C Sedtrans05 - a sediment transport model
C Preliminary test version
C Copyright (C) 2005 Urs Neumeier, Christian Ferrarin, Carl Amos
C and Georg Umgiesser.
C Sedtrans05 was developed at the ISMAR-CNR in Venice and the
C University of Southampton.
C Previous versions of Sedtrans (1992 and 1996) were developed at
C the Geological Survey of Canada, Bedford Institute of Oceanography.
C
C This program is free software; you can redistribute it and/or modify
C it under the terms of the GNU General Public License as published by
C the Free Software Foundation; either version 3 of the License, or
C (at your option) any later version. See file "licence.txt" in the
C Sedtrans05 directory for the full licence text, which can also be
C found at http://www.gnu.org/licenses/
C
C This program is distributed in the hope that it will be useful,
C but WITHOUT ANY WARRANTY; without even the implied warranty of
C MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C GNU General Public License for more details.
C **********************************************************************
C
C Revision Log:
C
C****************************************************************************
C****************************************************************************
C                  *** SUBROUTINE SEDTRANS05 ***
C****************************************************************************
C****************************************************************************

      SUBROUTINE SEDTRANS05(D,UZ,Z,CDIR,HT,PER,WDIR,GD,
     @BETA,RHOS,RHOW,IOPT1,VISC,CONC,BEDCHA,MAXBED,TIMEDR,AULVA,                                					   	!**INPUT VARIABLES**
     @
     @USTCRB,USTCRS,USTUP,UB,FCW,UA,U100,USTCWS,USTCW,Z0,RHEIGHT,
     @RLENGTH,QS,QSDIR,SEDM,SED,SEDDIR,FALL,C0A,EDRATE,ZS,TAOS,
     @TCONC)		!**OUTPUT VARIABLES**

      IMPLICIT NONE
      INCLUDE "sed_param.h"

C************* INPUT VARIABLES ******************

      INTEGER IOPT1             !SEDIMENT TRANSPORT FORMULA OPTION NUMBER
      DOUBLE PRECISION D        !WATER DEPTH (M)
      DOUBLE PRECISION UZ       !AMBIENT CURRENT AT HEIGHT Z ABOVE THE SEAFLOOR (M/S)
      DOUBLE PRECISION Z        !HEIGHT OF UZ ABOVE SEAFLOOR
      DOUBLE PRECISION CDIR     !DIRECTION OF AMBIENT CURRENT (DEGREES TRUE)
      DOUBLE PRECISION HT       !WAVE HEIGHT (M)
      DOUBLE PRECISION PER      !WAVE PERIOD (S)
      DOUBLE PRECISION WDIR     !WAVE PROPAGATION DIRECTION (DEGREES TRUE)
      DOUBLE PRECISION GD       !SEDIMENT GRAIN DIAMETER (M)
      DOUBLE PRECISION BETA     !BED SLOPE (DEGREE)
      DOUBLE PRECISION RHOS     !DENSITY OF SEDIMENT MINERAL(S)   (KG/M**3)
      DOUBLE PRECISION RHOW     !DENSITY OF FLUID (WATER)  (KG/M**3)
      DOUBLE PRECISION VISC     !DYNAMIC VISCOSITY OF THE FLUID (KG/M*SEC (OR N.S/M**2))

c cohesive
      DOUBLE PRECISION CONC(NBCONC) !COHESIVE SUSPENDED SEDIMENT CONCENTRATION (kg/m3)
      INTEGER MAXBED            ! upper bound of first dimension of BEDCHA
      DOUBLE PRECISION BEDCHA(MAXBED,3) ! bed characteristics in 3 column table
                                ! (1) depth below sediment surface (m)
                                ! (2) critical erosion stress (Pa)
                                ! (3) dry bulk density (kg/m**3)
      DOUBLE PRECISION TIMEDR   !Duration of call to Sedtrans (s)
      DOUBLE PRECISION AULVA    !fraction of bed area covered by the algae 'Ulva' (range 0-1)

C************* OUTPUT VARIABLES *****************

      DOUBLE PRECISION USTCRB   !CRITICAL SHEAR VEL FOR INITI OF BEDLOAD TRANS (M/SEC)
      DOUBLE PRECISION USTCRS   !CRITICAL SHEAR VEL FOR INITI OF SUSPENDED LOAD TRANSPORT (M/SEC)
      DOUBLE PRECISION USTUP    !CRITICAL SHEAR VEL FOR INITN OF SHEET FLOW TRANSPORT (M/SEC)
      DOUBLE PRECISION UB       !MAXIMUM WAVE INDUCED ORBITAL VELOCITY AT THE BOTTOM (M/S)
      DOUBLE PRECISION FCW      !BOTTOM (SKIN) FRICTION FACTOR
      DOUBLE PRECISION UA       !CURRENT SPEED TO BE USED IN BOTTOM STRESS CALC. (M/SEC)
      DOUBLE PRECISION U100     !CURRENT SPEED AT 1 M. ABOVE SEABED (M/SEC)
      DOUBLE PRECISION USTCWS	!COMBINED SKIN-FRICTION SHEAR VELOCITY OF GM
      DOUBLE PRECISION USTCW	!COMBINED TOTAL SHEAR VELOCITY OF GM
      DOUBLE PRECISION Z0       !BED ROUGHNESS LENGTH (M)
      DOUBLE PRECISION RHEIGHT	!PREDICTED RIPPLE HEIGHT
      DOUBLE PRECISION RLENGTH	!PREDICTED RIPPLE LENGTH
      DOUBLE PRECISION QS	!SUSPENDED SEDIMENT TRANSPORT RATE (KG/M/S)
      DOUBLE PRECISION QSDIR	!DIRECTION OF SUSPENDED SEDIMENT TRANSPORT (DEGREE)
      DOUBLE PRECISION SED	!TIME-AVERAGED NET SEDIMENT TRANSPORT AS VOLUME (M**3/S/M)
      DOUBLE PRECISION SEDM	!TIME-AVERAGED NET SEDIMENT TRANSPORT AS MASS (KG/S/M)
      DOUBLE PRECISION SEDDIR	!DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)
      DOUBLE PRECISION FALL     !SETTLING VELOCITY FOR NON-COHESIVE SEDIMENT (M/SEC)
      DOUBLE PRECISION C0A      !DEPTH AVERAGED REFERENCE CONCENTRATION AT Z0 (KG/M^3)

c cohesive
      DOUBLE PRECISION EDRATE  !mean erosion/deposition rate (kg/m^2/s)
                               !(positive: erosion, negative: deposition
      DOUBLE PRECISION ZS      !Height change in bed surface (m)
                               !(positive: erosion, negative: deposition)
      DOUBLE PRECISION TAOS    !solid transmitted stress due to Ulva (Pa)
      DOUBLE PRECISION TCONC   !final total suspended sediment concentration (kg/m**3)

      DOUBLE PRECISION VISK     !KINEMATIC VISCOSITY OF FLUID (M**2/SEC)

c local
      LOGICAL COHES             !YES=COHESIVE SEDIMENT
      DOUBLE PRECISION DX       !DIMENSIONLESS GRAIN SIZE

C**************************************************************************
C  INITIALIZE UNASSIGNED VARIABLES

      QS = 0.
      QSDIR = 0.
      C0 = 0.
      C0A = 0.
      SED = 0.
      SEDM = 0.
      TAOCWS = 0.
      USTCRB=0.
      USTCRS=0.
      USTUP=0.
      FALL=0.
      TB1=0.                  !ccf INTEL
      TB2=0.                  !ccf INTEL
      TS1=0.                  !ccf INTEL
      TS2=0.                  !ccf INTEL
      PERBED=0.               !ccf INTEL
      PERSUSP=0.              !ccf INTEL
      VISK=VISC/RHOW

      COHES = IOPT1 .EQ. 7	!COHESIVE SEDIMENT

C**************************************************************************
C CALCULATE WAVE-INDUCED BOTTOM PARTICLE VELOCITY AND ORBITAL DIAMETER
C
C OUTPUT VARIABLES:
C
C    UB = MAXIMUM WAVE INDUCED ORBITAL VELOCITY AT THE BOTTOM (M/S)
C    AB = EXCURSION LENGTH OF BOTTOM WAVE ORBIT (M)
C               (1/2 OF THE ORBITAL DIAMETER)
C    WL = WAVE LENGTH (M)

      CALL OSCIL(HT,PER,D,UB)

C***************************************************************************
C CALCULATE THRESHOLD CRITERIA FOR BEDLOAD, SUSPENDED LOAD AND
C SHEET FLOW NON-COHESIVE SEDIMENT TRANSPORT.
C THRESH SUBROUTINE NOT APPLICABLE FOR COHESIVE SEDIMENTS --> GOTO FRICFAC
C
C OUTPUT VARIABLES:
C
C        FALL = SETTLING VELOCITY FOR NON-COHESIVE SEDIMENT (M/SEC)
C      USTCRB = CRITICAL SHEAR VELOCITY FOR INITIATION OF BEDLOAD
C               TRANSPORT (M/SEC)
C      USTCRS = CRITICAL SHEAR VELOCITY FOR INITIATION OF SUSPENDED
C               LOAD TRANSPORT (M/SEC)
C       USTUP = CRITICAL SHEAR VELOCITY FOR INITIATION OF SHEET FLOW
C               TRANSPORT (M/SEC)
C          DX = DIMENSIONLESS GRAIN SIZE

      IF( .NOT. COHES ) CALL THRESH(VISK,GD,RHOS,RHOW,FALL,USTCRB,
     @USTCRS,USTUP,DX)

C**************************************************************************
C CALCULATE FRICTION FACTOR, AMBIENT CURRENT AND BOTTOM STRESSES
C
C OUTPUT VARIABLES:
C
c          Z0 = BED ROUGHNESS LENGTH (M)
C         Z0C = APPARENT BED ROUGHNESS LENGTH (M)
C         FCW = BOTTOM (SKIN) FRICTION FACTOR
C          UA = CURRENT SPEED TO BE USED IN BOTTOM STRESS CALC. (M/SEC)
C        PHIB = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS WITHIN THE
C               WAVE BOUNDARY LAYER (RADIANS)
C        U100 = CURRENT SPEED AT 1 M. ABOVE SEABED (M/SEC)
C      PHI100 = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS AT 1 M.
C               ABOVE SEABED (RADIANS)
C               NOTE:  PHI100 = PHIZ AS LONG AS PHIZ IS MEASURED
C               OUTSIDE THE WAVE BOUNDARY LAYER.
C       USTCS = CURRENT SKIN-FRICTION SHEAR VELOCITY OF GM
C       USTWS = WAVE SKIN-FRICTION SHEAR VELOCITY OF GM
C      USTCWS = COMBINED SKIN-FRICTION SHEAR VELOCITY OF GM
C     USTCWSE = EFFECTIVE COMBINED SKIN-FRICTION SHEAR VELOCITY
C     USTCWSB = TRANSPORT-RELATED COMBINED SHEAR VELOCITY
C        USTC = TOTAL CURRENT SHEAR VELOCITY OF GM
C        USTW = TOTAL WAVE SHEAR VELOCITY OF GM
C       USTCW = COMBINED TOTAL SHEAR VELOCITY OF GM
C     DELTACW = HEIGHT OF THE WAVE-CURRENT BOUNDARY LAYER
C     RHEIGHT = PREDICTED RIPPLE HEIGHT
C     RLENGTH = PREDICTED RIPPLE LENGTH
C     RPLCOEF = RIPPLE COEFFICIENT FOR SHEAR VELOCITY CONVERSION

      CALL FRICFAC(UZ,Z,CDIR,UB,PER,WDIR,GD,VISK,RHOW,
     @RHOS,USTCRB,USTUP,Z0,FCW,UA,U100,USTCWS,USTCW,RHEIGHT,RLENGTH)

      IF(USTCW.EQ.0) USTCW=MAX(USTC,USTW)
      IF(USTCWS.EQ.0) USTCWS=MAX(USTCS,USTWS)

C**************************************************************************
C IF COHESIVE COMPUTE THE TRANSPORT AND THEN EXIT

      IF ( COHES ) THEN

       CALL COHESIVE(CONC,BEDCHA,MAXBED,TIMEDR,USTCWS,U100,D,
     & RHOW,VISK,AULVA,EDRATE,ZS,SEDM,TCONC,TAOS)

       SEDDIR = CDIR
       RETURN
      END IF

C**************************************************************************
C CALCULATE THE DURATION OF THE DIFFERENT SEDIMENT TRANSPORT PHASES
C
C OUTPUT VARIABLES:
C
C         TB1 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH BEDLOAD
C               TRANSPORT CEASES (SEC)
C         TB2 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH BEDLOAD
C               TRANSPORT RECOMMENCES (SEC)
C         TS1 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH SUSPENDED
C               LOAD TRANSPORT CEASES (SEC)
C         TS2 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH SUSPENDED
C               LOAD TRANSPORT RECOMMENCES (SEC)
C      PERBED = PERCENTAGE OF TIME SPENT IN ONLY BEDLOAD TRANSPORT PHASE
C     PERSUSP = PERCENTAGE OF TIME SPENT IN SUSPENDED LOAD TRANSPORT PHASE
C

      CALL TIMING(RHOW,UA,UB,PER,U100,USTCRB,USTCRS,USTCWS)

C CALCULATE VELOCITY PROFILE, SUSPENDED SEDIMENT CONCENTRATION PROFILE
C AND THE SUSPENDED SEDIMENT TRANSPORT RATE AND DIRECTION

      CALL PROFL(D,RHOW,FALL,UB,CDIR,USTCWS,USTCW,USTCRB,USTCRS,
     @USTUP,Z0,QS,QSDIR,C0A)

C**************************************************************************
C CALCULATE SEDIMENT TRANSPORT RATE AND DIRECTION
C
C OUTPUT VARIABLES:
C
C    SED = TIME-AVERAGED NET SEDIMENT TRANSPORT AS VOLUME OF SEDIMENT SOLIDS
C          TRANSPORTED PER UNIT BED WIDTH PER UNIT TIME (M**3/S/M)
C    SEDM = TIME-AVERAGED NET SEDIMENT TRANSPORT AS MASS OF SEDIMENT SOLIDS
C           TRANSPORTED PER UNIT BED WIDTH PER UNIT TIME (KG/S/M)
C    SEDDIR = DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)

      CALL TRANSPO(D,UA,UB,U100,PER,GD,BETA,RHOS,RHOW,USTCRB,
     @VISK,FCW,USTCWS,HT,CDIR,WDIR,IOPT1,DX,FALL,SED,SEDM,SEDDIR)

      RETURN
      END

C****************************************************************************
C****************************************************************************

C **********************************************************
C SUBROUTINE OSCIL
C **********************************************************
      SUBROUTINE OSCIL(HT,PER,D,UB)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INCLUDE "sed_param.h"

C  THIS SUBROUTINE CALCULATES WAVE-INDUCED BOTTOM PARTICLE VELOCITY
C  AND DISPLACEMENT USING LINEAR WAVE THEORY.  A CHECK IS ALSO MADE
C  FOR WAVE BREAKING.
C
C  INPUT VARIABLES:
C         HT = WAVE HEIGHT (M)       (INDATA96 file)
C        PER = WAVE PERIOD (SEC)     (INDATA96 file)
C          D = WATER DEPTH (M)       (INDATA96 file)
C
C  OUTPUT VARIABLES:
C         UB = MAX. WAVE-INDUCED BOTTOM HORIZ. PARTICLE VELOCITY (M/SEC)
C         AB = MAX. WAVE-INDUCED BOTTOM HORIZ. PARTICLE DISPLACEMENT (M)
C              (1/2 OF THE ORBIT SIZE)
C         WL = WAVELENGTH FROM LWT DISPERSION EQUATION (M)
C
C  INTERMEDIATE VARIABLES:
C          G = ACCELERATION DUE TO GRAVITY (M/SEC**2)
C        WL0 = DEEP WATER WAVE LENGTH (M)
C          W = WAVE ANGULAR FREQUENCY (RAD/SEC)
C        RKD = K*D  ( K = WAVE NUMBER (RAD/M) )
C         HB = BREAKING WAVE HEIGHT FOR GIVEN WAVE PERIOD AND WATER DEPTH (M)

      UB=0.0
      AB=0.0
      WL=0.0

C---------------------------------------------------------------------
C CHECK FOR CURRENT ONLY CASE (INCLUDING 'DEEP WATER' WAVE CONDITIONS)
C
C   FOR DEEP WATER WAVE CONDITIONS THE NORMAL CRITERION IS D/WL GREATER
C   THAN 0.5. TO ENSURE NO APPRECIABLE WAVE INDUCED BOTTOM STRESS, THIS
C   CODE USES THE CRITERION OF D/WL GREATER THAN 2.0

      IF (PER .EQ. 0) GOTO 30
      WL0 = G*PER*PER/(2*PII)

      IF ((D/WL0) .GT. 2.) RETURN

C---------------------------------------------------------------------
C  CALCULATE WAVELENGTH BY NEWTON-RAPHSON SOLUTION OF LWT DISPERSION
C  EQUATION.

      W=2.*PII/PER
      RKD0=W**2*D/G
      RKD=RKD0
  20  CONTINUE
      DKD=(1./TANH(RKD)-RKD/RKD0)/(1./RKD0+1./SINH(RKD)**2)
      RKD=RKD+DKD
      IF (ABS(DKD) .GE. 1.0E-4) GO TO 20
      WL=WL0*TANH(RKD)

C---------------------------------------------------------------------
C  CALCULATE WAVE-INDUCED BOTTOM PARTICLE VELOCITY AND ORBIT SIZE

C CONVENTIONALLY: UB=HT*G*PER/(2*WL*COSH(2*PII*D/WL))
C THE MORE EFFICIENT ALGORITH IS:
      UB=PII*HT/(PER*SINH(RKD))

C CONVENTIONALLY: AB=HT/(2*SINH(2*PII*D/WL))
C THE MORE EFFICIENT ALGORITH IS:
      AB=UB/W
C---------------------------------------------------------------------

 30   RETURN
      END

C *****************************************************
C SUBROUTINE THRESHOLD
C *****************************************************
      SUBROUTINE THRESH(VISK,GD,RHOS,RHOW,FALL,USTCRB,USTCRS,USTUP,DX)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INCLUDE "sed_param.h"

C  THIS SUBROUTINE CALCULATES THE THRESHOLD SHEAR VELOCITIES FOR BEDLOAD,
C  SUSPENDED LOAD, AND SHEET FLOW SEDIMENT TRANSPORT. THE CRITICAL STRESS
C  FOR BEDLOAD TRANSPORT IS BASED ON THE VAN RIJN METHOD.
C  THE CRITICAL STRESS FOR SUSPENDED LOAD IS BASED ON THE VAN RIJN, WHERE
C  THE PARTICLE FALL VELOCITY IS AS GIVEN BY SOULSBY. THE SHEET FLOW
C  CRITICAL SHEAR STRESS IS GIVEN BY LEE AND AMOS.
C
C INPUT VARIABLES:
C     VISK = KINEMATIC VISCOSITY OF FLUID (M**2/SEC)
C       GD = SEDIMENT GRAIN SIZE (M)                (INDATA96 file)
C     RHOS = SEDIMENT DENSITY (KG/M**3)             (READIN subroutine)
C     RHOW = FLUID DENSITY (KG/M**3)                (READIN subroutine)
C
C OUTPUT VARIABLES:
C     FALL = FALL VELOCITY OF SEDIMENT GRAINS AS GIVEN BY SOULSBY (M/SEC)
C   USTCRB = CRITICAL SHEAR VEL. FOR INIT. OF BEDLOAD  (M/SEC)
C   USTCRS = CRITICAL SHEAR VEL. FOR INIT. OF SUSPENDED (M/SEC)
C    USTUP = CRITICAL SHEAR VEL. FOR INIT. OF UPPER PLANE BED SHEET FLOW (M/SEC)
C       DX = DIMENSIONLESS GRAIN SIZE
C
C INTERMEDIATE VARIABLES:
C        G = ACCELERATION DUE TO GRAVITY (M/SEC**2)
C     DRHO = SEDIMENT DENSITY - FLUID DENSITY (KG/M**3)
C    YALIN = YALIN PARAMETER
C   GYALIN = LOG10 OF THE YALIN PARAMETER
C      SCR = SHIELDS PARAMETER
C      AUX = AUX VARIABLE

C INITIALIZE CONSTANTS
      DRHO = RHOS-RHOW
      AUX = (DRHO*G*GD)/RHOW

C COMPUTE THE DIMENSIONLESS PARTICLE DIAMETER
      DX = GD * (((DRHO/RHOW)*G)/VISK**2.)**(1./3.)

C COMPUTE FALL VELOCITY (Soulsby, 1997)
      FALL = (VISK/GD)*((10.36**2. + 1.049*DX**3.)**0.5 - 10.36)

C-----------------------------------------------------------------
C CALCULATE THRESHOLD SHEAR VELOCITY FOR BEDLOAD TRANSPORT, USTCRB
C-----------------------------------------------------------------
C GET SHIELDS PARAMETER USING YALIN METHOD MODIFIED FROM MILLER ET AL. (1977)

      YALIN=SQRT((DRHO*G*GD**3.)/(RHOW*VISK**2.))
      GYALIN=dLOG10(YALIN)
      IF (YALIN .GE. 3000) THEN
         SCR=0.045
      ELSE IF (YALIN .LE. 100) THEN
         SCR=10.**((0.041*GYALIN**2)-0.356*GYALIN-0.977)
      ELSE
         SCR=10.**(0.132*GYALIN-1.804)
      ENDIF

C CONVERT SHIELDS PARAMETER TO SHEAR VELOCITY
      USTCRB=SQRT(SCR*AUX)

C--------------------------------------------------------------------------
C CALCULATE THRESHOLD SHEAR VELOCITY FOR SUSPENDED LOAD TRANSPORT, USTCRS
C--------------------------------------------------------------------------
C GET THE CRITICAL USTCRS/FALL RATIO for SUSPENSION (Van Rijn, 1984)

      IF(DX.GT.1..AND.DX.LE.10.)THEN
        SCR = 4./DX
      ELSE
        SCR = 0.4
      ENDIF

C COMPUTE THRESHOLD SHEAR VELOCITY
      USTCRS=FALL*SCR
      USTCRS = max(USTCRS,USTCRB)

C--------------------------------------------------------------------------
C CALCULATE THRESHOLD SHEAR VELOCITY FOR SHEET FLOW TRANSPORT, USTUP
C--------------------------------------------------------------------------
C CALCULATE SHEETFLOW SHIELDS PARAMETER ACCORDING TO LI AND AMOS
c      SCR = 0.172*(100.*GD)**(-0.376)
      SCR = 0.413*(1000*GD)**(-0.4)

C CONVERT SHIELDS PARAMETER TO SHEAR VELOCITY
      USTUP=SQRT(SCR*AUX)

      RETURN
      END

C **********************************************************
C SUBROUTINE FRICFAC
C **********************************************************

      SUBROUTINE FRICFAC(UZ,Z,CDIR,UB,PER,WDIR,GD,VISK,RHOW,
     @RHOS,USTCRB,USTUP,Z0,FCW,UA,U100,USTCWS,USTCW,RHEIGHT,RLENGTH)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INCLUDE "sed_param.h"

      LOGICAL COHES

C  THIS SUBROUTINE CALCULATES THE FRICTION FACTOR, SHEAR VELOCITIES AND
C  RIPPLE DIMENSIONS FOR VARIOUS WAVE AND CURRENT CONDITIONS.

C  CASE A: FOR SI92 DATA     YES
C  CASE B: FOR SI82 DATA     NO

C  FOR COMBINED FLOW, GRAIN-SIZE ROUGHNESS IS FIRST USED TO OBTAIN THE SKIN-
C  FRICTION SHEAR VELOCITY WHICH IS USED TO CALCULATE THE BEDLOAD ROUGHNESS.
C  THE COMBINED GRAIN AND BEDLOAD ROUGHNESS IS USED TO OBTAIN A TRANSPORT-
C  RELATED SHEAR VELOCITY WHICH IS USED TO COMPUTE RIPPLE GEOMETRY AND
C  DETERMINE IF TRANSPORT IS IN SUSPENSION OR SHEETFLOW MODES.
C  FOR COHESIVE SEDIMENTS USE CONSTANT ROUGHNESS LENGHT (SOULSBY 1997)
C  AND DO NOT PREDICT RIPPLE DIMENSION
C
C INPUT VARIABLES:
C         UZ = CURRENT SPEED AT HEIGHT Z (M) ABOVE SEABED (M/SEC)    (INDATA96 file)
C          Z = HEIGHT ABOVE SEABED AT WHICH CURRENT IS MEASURED (M)  (INDATA96 file)
C       CDIR = CURRENT DIRECTION AT 1 M. ABOVE SEABED (AZIMUTH)      (INDATA96 file)
C        PER = WAVE PERIOD (SEC)                                     (INDATA96 file)
C       WDIR = WAVE DIRECTION (AZIMUTH)                              (INDATA96 file)
C         GD = SEDIMENT GRAIN SIZE (M)                               (INDATA96 file)
C      RHINP = INPUT RIPPLE HEIGHT (M)                               (INDATA96 file)
C      RLINP = INPUT RIPPLE LENGTH (M)                               (INDATA96 file)
C       RHOW = DENSITY OF FLUID (WATER)  (KG/M**3)                   (READIN subr)
C       RHOS = DENSITY OF SEDIMENT GRAIN  (KG/M**3)                  (READIN subr)
C         UB = MAXIMUM WAVE-INDUCED BOTTOM PARTICLE VELOCITY (M/SEC) (OSCIL subr)
C         AB = MAXIMUM WAVE-INDUCED BOTTOM PARTICLE DISPLACEMENT (M) (OSCIL subr)
C     USTCRB = CRITICAL SHEAR VELOCITY FOR BEDLOAD TRANSPORT (M/SEC) (THRESH subr)
C      USTUP = CRITICAL SHEAR VELOCITY FOR INITIATION OF UPPER
C              PLANE BED SHEET FLOW (M/SEC)                          (THRESH subr)
C       VISK = KINEMATIC VISCOSITY OF FLUID (M**2/SEC)               (THRESH subr)
C      COHES = IF YES = COHESIVE SEDIMENTS
C
C OUTPUT VARIABLES:
C         Z0 = BED ROUGHNESS LENGTH (M)
C        Z0C = APPARENT BED ROUGHNESS LENGTH (M)
C        FCW = BOTTOM FRICTION FACTOR
C         UA = CURRENT SPEED AT THE TOP OF THE WAVE-CURRENT BOUNDARY LAYER
C              TO BE USED IN BOTTOM STRESS CALC. (M/SEC)
C       PHIB = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS WITHIN THE
C              WAVE BOUNDARY LAYER (RADIANS)
C       U100 = CURRENT SPEED AT 1 M. ABOVE SEABED (M/SEC)
C     PHI100 = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS AT 1 M.
C              ABOVE SEABED (RADIANS)
C                  NOTE:  PHI100 = PHIZ AS LONG AS PHIZ IS MEASURED
C                  OUTSIDE THE WAVE BOUNDARY LAYER.
C      USTCS = CURRENT SKIN-FRICTION SHEAR VELOCITY OF GM
C      USTWS = WAVE SKIN-FRICTION SHEAR VELOCITY OF GM
C     USTCWS = COMBINED SKIN-FRICTION SHEAR VELOCITY OF GM
C    USTCWSE = EFFECTIVE COMBINED SKIN-FRICTION SHEAR VELOCITY
C    USTCWSB = TRANSPORT-RELATED COMBINED SHEAR VELOCITY
C       USTC = TOTAL CURRENT SHEAR VELOCITY OF GM
C       USTW = TOTAL WAVE SHEAR VELOCITY OF GM
C      USTCW = TOTAL COMBINED SHEAR VELOCITY OF GM
C    DELTACW = HEIGHT OF THE WAVE-CURRENT BOUNDARY LAYER
C    RHEIGHT = PREDICTED RIPPLE HEIGHT (M)
C    RLENGTH = PREDICTED RIPPLE LENGTH (M)
C    RPLCOEF = RIPPLE COEFFICIENT FOR SHEAR VELOCITY CONVERSION
C      USTBF = CRITICAL SHEAR VELOCITY FOR RIPPLE BREAKOFF
C
C INTERMEDIATE VARIABLES:
C        RKB = BOTTOM ROUGHNESS HEIGHT (M)
C      DELTA = USTCS CONVERGENCE CRITERION FACTOR
C        FWS = SKIN-FRICTION FACTOR
C       FBAD = TOTAL FRICTION FACTOR INCLUDING FORM DRAG
C       UBAD = CURRENT SPEED NEGLECTING FORM DRAG (M/SEC)
C     PHIBAD = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS, WITHIN
C              WAVE B.L. AND NEGLECTING FORM DRAG (RADIANS)
C      RATIO = UA/UB;  DETERMINES VALIDITY OF EQUATION OF MOTION
C              USED BY GRANT AND MADSEN (1979)
C        SKB = PREDICTED GRAIN + BEDLOAD ROUGHNESS HEIGHT
C        BKB = PREDICTED BEDLOAD ROUGHNESS HEIGHT
C        HTM = BEDLOAD LAYER HEIGHT

C INITIALIZE PARAMETERS
        FCW=0.0
        U100=0.0
        PHI100=0.
        PHIB=0.
        USTCS=0.0
        USTWS=0.0
        USTCWS=0.0
        USTC=0.0
        USTW=0.0
        USTCW=0.0
        USTCWSE=0.0
        USTCWSB=0.0
        USTBF=0.0
        Z0=0.0
        Z0C=0.0
        DELTACW=0.0
        RPLCOEF=1.
        BKB=0.0
        SKB=0.0
        TKB=0.0
        RHINP = RHEIGHT
        RLINP = RLENGTH

        COHES = GD.LE.0.000063		!true=cohesive; false=non cohesive

C*********************
C PURE CURRENT CASE
C*********************
      IF (UB .LT. 0.01) THEN

C GET PRELIMINARY BED ROUGHNESS HEIGHT RKB ACCORDING TO GRANT AND MADSEN
C (1982). IF THERE IS NO MEASUREMENT OF RIPPLE HEIGHTS, RKB=2.5*GD, OTHERWISE
C USE THE MEASURED INPUT RIPPLE HEIGHT AND LENGTH TO OBTAIN RKB=27.7*RHINP
C *RHINP/RLINP. FOR COHESIVE SEDIMENTS USE COSTANT BED ROUGHNESS HEIGHT

        IF ( COHES ) THEN
          RKB = Z0COH*30.
          FCW = FCWCOH
        ELSE
          IF (RHINP .EQ. 0) THEN
            RKB=2.5*GD
            FCW = 2.6E-3
          ELSE
            RKB=27.7*RHINP*RHINP/RLINP
            FCW = 6.0E-3
          ENDIF
        ENDIF

C CALL FRIC1 TO OBTAIN THE PRELIMINARY ESTIMATES OF "UA","U100","USTC"
        CALL FRIC1(UZ,Z,GD,RKB,UA,U100,USTC)

C COMPUTE PRELIMINARY SKIN-FRICTION CURRENT SHEAR VELOCITY
        USTCS=SQRT(0.5*FCW*U100**2)

C ASSIGN AN ARBITRARY VALUE TO THE USTCS CONVERGENCE CRITERION DELTA
        DELTA=1.0
 100    IF (DELTA .LT. 0.0001) GOTO 200

C PREDICT CURRENT RIPPLE DIMENSIONS:
C FOR NO-TRANSPORT CASE OR COARSE AND VERY-COARSE SANDS OR COHESIVE SEDIMENTS,
C BEDFORM DIMENSION WILL NOT BE PREDICTED AND INPUT VALUES WILL BE USED.
C OTHERWISE, RIPPLE HEIGHT AND LENGTH WILL BE PREDICTED ACCORDING TO YALIN
C (1964) AND ALLEN (1970), RESPECTIVELY.
        IF (USTCS .LT. USTCRB .OR. GD .GE. 0.0005 .OR. COHES) THEN
           RHEIGHT=RHINP
           RLENGTH=RLINP
           GOTO 200				!ccf
        ELSE

C FOR SHEET-FLOW, RIPPLE HEIGHT AND LENGTH WILL BE 0
           IF (USTCS .GE. USTUP) THEN
              RHEIGHT=0
              RLENGTH=0
           ELSE
              RLENGTH=1000*GD
              RHEIGHT=0.00074*(100*RLENGTH)**1.19
          ENDIF

        ENDIF
        IF (RHEIGHT .EQ. 0) THEN
           USTC=USTCS
           RKB=30*EXP(LOG(Z)-0.4*UZ/USTC)
           FCW = 2.6E-3
        ELSE
           RKB=27.7*RHEIGHT*RHEIGHT/RLENGTH
           FCW = 6.0E-3
        ENDIF

C CALL FRIC1 WITH NEW RKB TO OBTAIN NEW U100 AND USTC
        CALL FRIC1(UZ,Z,GD,RKB,UA,U100,USTC)

C ASSIGN THE INITIAL USTCS TO A TEMPORARY VARIABLE
        USTCSP=USTCS

C COMPUTE THE NEW SKIN-FRICTION CURRENT SHEAR VELOCITY
        USTCS=SQRT(0.5*FCW*U100**2)

C OBTAIN THE USTCS CONVERGENCE CRITERION DELTA
        DELTA=DABS(USTCSP/USTCS-1)

        if (USTCS .GE. USTUP) delta=0.00001             !ccf
        IF (USTCSP.EQ.0..AND.USTCS.EQ.0.)THEN
          DELTA=0.00001
        ENDIF

C GOTO 100 TO COMPARE THE DELTA VALUE WITH THE SET CRITERION VALUE
        GOTO 100

 200    CONTINUE

C GET FINAL BED ROUGHNESS Z0
        Z0=RKB/30.

        RETURN

      ENDIF

C*************************
C WAVES AND CURRENT CASE
C*************************

      IF (UZ .NE. 0.0) THEN

      PHI100=DMIN1(ABS(CDIR-WDIR),ABS(180.-ABS(CDIR-WDIR)),
     @         360.-ABS(CDIR-WDIR))*ASIN(1.)/90.
      PHIB=PHI100

C COMPUTE SKIN-FRICTION "FCW" AND "UST'S" BASED ON GRAIN ROUGHNESS HEIGHT GKB ONLY
C FOR COHESIVE SEDIMENTS USE COSTANT BED ROUGHNESS HEIGHT.
      IF ( COHES ) THEN
        GKB = Z0COH*30.
      ELSE
        GKB = 2.5*GD
      ENDIF

      CALL FRIC2(UZ,Z,PHI100,UB,PER,GKB,RKBC,FCW,UA,PHIB,
     @U100,USTCS,USTWS,USTCWS,DELTACW)

      IF ( COHES ) THEN
        RHEIGHT = RHINP
        RLENGTH = RLINP
        USTCWSE = USTCWS
        TKB = GKB
        GOTO 543
      ENDIF

C COMPUTE INITIAL BED ROUGHNESS HEIGHTS BASED ON SKIN-FRICTION UST'S
      CALL ROUGH(VISK,RHINP,RLINP,USTCS,USTWS,USTCWS,USTCRB,
     @USTUP,GD,RHOW,RHOS,RHEIGHT,RLENGTH,SKB,HTM,TKB,USTCWSE,
     @RPLCOEF,USTBF)

      BKB=180*HTM
      SKB=2.5*GD+BKB

C COMPUTE TRANSPORT-RELATED FCWB AND UST'S USING THE SUM OF GRAIN AND BEDLOAD
C ROUGHNESS HEIGHTS, SKB.
      CALL FRIC2(UZ,Z,PHI100,UB,PER,SKB,RKBC,FCWB,UA,PHIB,
     @U100,USTCSB,USTWSB,USTCWSB,DELTACW)

C COMPUTE FINAL BED ROUGHNESS HEIGHTS BASED ON TRANSPORT-RELATED UST'S.
C USE PREDICTED RIPPLE GEOMETRY FROM ROUGH AS INPUTS IF THE RIPPLE-ENHANCED
C SHEAR VELOCITY U*CWSE IS LARGER THAN BEDLOAD THRESHOLD SHEAR VELOCITY U*CRB

      CALL ROUGH(VISK,RHINP,RLINP,USTCSB,USTWSB,USTCWSB,USTCRB,
     @USTUP,GD,RHOW,RHOS,RHEIGHT,RLENGTH,SKB,HTM,TKB,USTCWSE,
     @RPLCOEF,USTBF)

C COMPUTE TOTAL FCW (FBAD) AND UST'S BASED ON TOTAL ROUGHNESS HEIGHT TKB.
      CALL FRIC2(UZ,Z,PHI100,UB,PER,TKB,RKBC,FBAD,UA,PHIB,
     @U100,USTC,USTW,USTCW,DELTACW)

C OBTAIN BED ROUGHNESS Z0, APPARENT BED ROUGHNESS Z0C
543   CONTINUE
      Z0=TKB/30
      RKB = TKB
      Z0C=RKBC

      RETURN
      ENDIF

C******************
C PURE WAVES CASE
C******************
C CALL FRIC3 USING MAX WAVE-INDUCED BOTTOM PARTICLE VELOCITY "AB"
C AND GRAIN SIZE "GD" TO COMPUTE SKIN-FRICTION FWS AND U*WS
C FOR COHESIVE SEDIMENTS USE COSTANT BED ROUGHNESS HEIGHT
      IF ( COHES ) THEN
        RKB = Z0COH*30.
      ELSE
        RKB = GD
      ENDIF

      CALL FRIC3(AB,RKB,FCW)
      UA=0.0
      W=2.*PII/PER
      USTWS=SQRT(0.5*FCW*UB**2)

C PREDICT WAVE RIPPLE DIMENSIONS. FOR NO-TRANSPORT CASE OR COARSE AND
C VERY-COARSE SANDS OR COHESIVE SEDIMENTS, BEDFORM DIMENSION WILL NOT
C BE PREDICTED AND INPUT VALUES WILL BE USED
      IF (USTWS .LT. USTCRB .OR. GD .GE. 0.0005 .OR. COHES) THEN
         RHEIGHT=RHINP
         RLENGTH=RLINP
         GOTO 432
      ELSE

C FOR FINE OR MEDIUM SAND IN ACTIVE TRANSPORT, RIPPLES ARE PREDICTED
C ACCORDING TO BOYD ET AL. (1988) AND ALLEN (1970)
         IF (USTWS .GE. USTUP) THEN
            RHEIGHT=0
            RLENGTH=0
         ELSE
            RLENGTH=AB*557*(UB*AB/VISK)**(-0.68)
            RHEIGHT=0.00074*(100*RLENGTH)**1.19
         ENDIF
      ENDIF

      IF (RLENGTH .EQ. 0.) THEN
         RKB=2.5*GD
      ELSE
         RKB=27.7*RHEIGHT*RHEIGHT/RLENGTH
      ENDIF

C CALL FRIC3 AGAIN USING NEW ROUGHNESS HEIGHT TO COMPUTE THE TOTAL FW AND U*W
      CALL FRIC3(AB,RKB,FCW)
      USTW=SQRT(0.5*FCW*UB**2)

432   CONTINUE
      DELTACW=2.*0.4*USTW/W
      Z0=RKB/30

      RETURN
      END

C**************************************************************************
C**************************************************************************
      SUBROUTINE FRIC1(UZ,Z,GD,RKB,UA,U100,USTC)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C  THIS SUBROUTINE CALCULATES THE BOTTOM FRICTION FACTOR FOR THE PURE
C  CURRENT CASE. A CONSTANT FRICTION FACTOR IS ASSUMED, BASED ON THE
C  WORK OF STERNBERG (1971).
C
C  INPUT VARIABLES:
C         UZ = CURRENT SPEED AT HEIGHT Z (M) ABOVE SEABED (M/SEC)
C          Z = HEIGHT ABOVE SEABED AT WHICH CURRENT IS MEASURED (M)
C         GD = SEDIMENT GRAIN SIZE (M)
C        RKB = BOTTOM ROUGHNESS (M)
C
C  OUTPUT VARIABLES:
C         UA = CURRENT SPEED TO BE USED IN BOTTOM STRESS CALC. (M/SEC)
C       U100 = CURRENT SPEED AT 1 M. ABOVE SEABED (M/SEC)
C       USTC = TOTAL CURRENT SHEAR VELOCITY OF GM (M/SEC)

      IF(RKB .EQ. 0.0) RKB=2.5*GD
      USTC=0.4*UZ/LOG(30*Z/RKB)
      U100=(USTC/0.4)*LOG(1*30/RKB)
      UA=U100
      RETURN
      END

C**************************************************************************
C**************************************************************************
      SUBROUTINE FRIC2(UZ,Z,PHI100,UB,PER,RKB,RKBC,FCW,UA,PHIB,
     @U100,USTC,USTW,USTCW,DELTACW)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      COMMON /MCONST/ G,PII
      SAVE /MCONST/

C  THIS SUBROUTINE CALCULATES THE FRICTION FACTOR FOR COMBINED WAVE AND
C  CURRENT CONDITIONS USING THE METHOD OF GRANT AND MADSEN (1986). THIS
C  METHOD IS NOT VALID FOR UA/UB > 1.0 (APPROXIMATELY) DUE TO THE REL-
C  ATIVE IMPORTANCE OF THE CONVECTIVE ACCELERATION TERMS IN THE EQUATION
C  OF MOTION.
C
C  INPUT VARIABLES:
C         UZ = CURRENT SPEED AT HEIGHT Z (M) ABOVE SEABED (M/SEC)
C     PHI100 = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS AT 1 M.
C              ABOVE SEABED (RADIANS)  (NB:  PHI100 = PHIZ)
C         UB = MAXIMUM WAVE-INDUCED BOTTOM PARTICLE VELOCITY (M/SEC)
C        PER = WAVE PERIOD (SEC)
C        RKB = BOTTOM ROUGHNESS HEIGHT (M)
C
C  OUTPUT VARIABLES:
C        FCW = BOTTOM FRICTION FACTOR FOR THE COMBINED CASE
C         UA = CURRENT SPEED TO BE USED IN BOTTOM STRESS CALC. (M/SEC)
C       U100 = CURRENT SPEED AT 1 M. ABOVE SEABED (M/SEC)
C       PHIB = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS WITHIN THE
C              WAVE BOUNDARY LAYER (RADIANS)
C       RKBC = APPARENT BOTTOM ROUGHNESS (M)
C       USTC = CURRENT SHEAR VELOCITY OF GM (M/SEC)
C       USTW = WAVE SHEAR VELOCITY OF GM (M/SEC)
C      USTCW = COMBINED SHEAR VELOCITY OF GM (M/SEC)
C    DELTACW = THICKNESS OF THE WAVE-CURRENT BOUNDARY LAYER
C
C  INTERMEDIATE VARIABLES:
C          W = WAVE ANGULAR FREQUENCY (RAD/SEC)
C         Z0 = DYNAMIC BOTTOM ROUGHNESS LENGTH
C         CR = FACTOR DESCRIBING RELATIVE RATIO OF USTC/USTW
C      DELTA = ITERATION CRITERION FOR UST CALCULATION
C       TEMP = TEMPORARY VARIABLE

C  INITIALIZE ITERATION PARAMETERS

      W=2.*PII/PER
      PHIB=PHI100
      DELTA=1.0
      CR=1.0
      FCW=0.01

C CALCULATE UST'S BY ITERATION (GM,1986)
 10   IF (DELTA .LT. 0.00001) GO TO 200
      Z0=RKB/30.
      TEMP=CR*UB/(Z0*W)
C INITIALIZE THE ITERATION CRITERION EPSILON
      EPSILON=1.0
 50   IF (EPSILON .LT. 0.00001) GO TO 100

C CALCULATE FCW ACCORDING TO GM (1986). NEWTON-RAPHSON SOLUTION IS USED IN
C ITERATION.
      X=4*SQRT(FCW)
      A=0.24*X-1.65+DLOG10(TEMP*X)-1/X
      B=0.24+1/X**2+1/(X*DLOG(10.0D00))
      DX=A/B
      XNEW=X-DX
      FCWNEW=(XNEW/4)**2
      EPSILON=DABS(FCWNEW/FCW-1)
      FCW=FCWNEW
      GO TO 50
 100  CONTINUE
C     CALCULATE USTW, USTCW AND DELTACW (BOUNDARY LAYER THICKNESS)
      USTW=SQRT(0.5*CR*FCW*UB**2)
      USTCW=SQRT(CR)*USTW
      DELTACW=2.*0.4*USTCW/W        !ggu error in article -> must be omega
C---- CALCULATE CURRENT SHEAR VELOCITY USTC ------------------------
C     FOR DELTACW=Z0, NO WAVE EFFECT AND PURE CURRENT ASSUMED
      IF (DELTACW .LE. Z0) THEN
         FCW=6.0E-3
         U100=UZ*LOG(30.0/RKB)/LOG(30.*Z/RKB)
         UA=U100
         PHIB=0.0
         USTC=SQRT(0.5*FCW*U100**2)
         USTCW=USTC
         USTW=0						!ccf INTEL
C GET FINAL BED ROUGHNESS AND BED ROUGHNESS HEIGHT USING LOG LAW
         Z0=EXP(LOG(Z)-UZ*0.4/USTC)
         RKB=30*Z0
         RKBC=RKB
         RETURN
      ENDIF
      AA=DLOG(DELTACW/Z0)/USTCW
      BB=DLOG(Z/DELTACW)
      CC=-0.4*UZ
      DD=SQRT(BB**2-4*AA*CC)
      USTC=0.5*(-BB+DD)/AA
      RKBC=DELTACW*EXP(-AA*USTC)
      CRNEW=SQRT(1.0+2*(USTC/USTW)**2*COS(PHIB)
     @      +(USTC/USTW)**4)
      DELTA=DABS(CRNEW/CR-1)
      CR=CRNEW
      GO TO 10

 200  CONTINUE
C CALCULATE VELOCITY AT THE TOP OF THE WAVE-CURRENT BOUNDARY LAYER
      UA=(USTC/0.4)*DLOG(DELTACW/RKBC)
C CALCULATE VELOCITY AT 1M ABOVE THE BOTTOM
      IF (DELTACW .GT. 1.) THEN
        U100=(USTC/USTCW)*(USTC/0.4)*DLOG(1.0D00/Z0)
      ELSE
        U100=(USTC/0.4)*DLOG(1.0D00/RKBC)
      ENDIF

      RETURN
      END

C**************************************************************************
C**************************************************************************
      SUBROUTINE FRIC3(AB,RKB,FCW)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C  THIS SUBROUTINE CALCULATES THE BOTTOM FRICTION FACTOR FOR THE PURE
C  WAVE CONDITION USING THE METHOD OF JONSSON (1966) AS MODIFIED BY
C  NIELSEN (1979).
C
C  INPUT VARIABLES:
C         AB = MAXIMUM WAVE-INDUCED BOTTOM PARTICLE DISPLACEMENT (M)
C        RKB = BOTTOM ROUGHNESS HEIGHT (M)
C
C  OUTPUT VARIABLES:
C        FCW = BOTTOM FRICTION FACTOR FOR THE PURE WAVE CASE

      FCW=DMIN1(EXP(5.213*(RKB/AB)**0.194-5.977),0.28D0)
      RETURN
      END

C**************************************************************************
C**************************************************************************
      SUBROUTINE ROUGH(VISK,RHINP,RLINP,USTCS,USTWS,USTCWS,USTCRB,
     @USTUP,GD,RHOW,RHOS,RHEIGHT,RLENGTH,SKB,HTM,TKB,USTCWSE,
     @RPLCOEF,USTBF)

      IMPLICIT DOUBLE PRECISION(A-H,K,O-Z)

      COMMON /MCONST/ G,PII
      SAVE /MCONST/

C  THIS SUBROUTINE USES SKIN-FRICTION SHEAR VELOCITIES TO CALCULATE THE
C  INITIAL RIPPLE GEOMETRY AND VARIOUS ROUGHNESS HEIGHTS BASED ON THE GM86
C  COMBINED-FLOW BBL MODEL AND THE LATEST SIB DATA
C
C  INPUT VARIABLES
C      VISK = KINEMATIC VISCOSITY OF FLUID (M**2/SEC)
C     RHINP = INITIAL RIPPLE HEIGHT (M)
C     RLINP = INITIAL RIPPLE LENGTH (M)
C     USTCS = GM CURRENT SKINFRICTION SHEAR VELOCITY (M/S)
C     USTWS = GM WAVE SKINFRICTION SHEAR VELOCITY (M/S)
C    USTCWS = GM COMBINED SKINFRICTION SHEAR VELOCITY (M/S)
C    USTCRB = CRITICAL SHEAR VELOCITY FOR THE INITIATION OF BEDLOAD TRANSPORT
C     USTUP = CRITICAL SHEAR VELOCITY FOR UPPER PLANE BED
C        GD = SEDIMENT GRAIN SIZE
C      RHOW = FLUID DENSITY; RHOS=SEDIMENT GRAIN DENSITY
C      RHOS = SEDIMENT DENSITY;
C
C  OUTPUT VARIABLES
C    RHEIGHT = PREDICTED RIPPLE HEIGHT
C    RLENGTH = PREDICTED RIPPLE LENGTH
C        SKB = PREDICTED GRAIN + BEDLOAD ROUGHNESS HEIGHT
C        HTM = BEDLOAD LAYER HEIGHT
C        TKB = PREDICTED TOTAL BOTTOM ROUGHNESS HEIGHT
C    USTCWSE = EFFECTIVE SHEAR VELOCITY AT THE RIPPLE CREST
C    RPLCOEF = UST CONVERSION COEFFICIENT
C      USTBF = CRITICAL SHEAR VELOCITY FOR RIPPLE BREAKOFF
C
C  INTERMEDIATE VARIABLES
C          G = GRAVITY ACCELERATION
C        SST = DIMENTIONLESS SEDIMENT GRAIN SIZE PARAMETER
C      PSICR = CRITICAL SHIELDS PARAMETER FOR BEDLOAD TRANSPORT
C      PSIBF = GM82 CRITICAL SHIELDS PARAMETER FOR RIPPLE BREAKOFF
C        GKB = GRAIN ROUGHNESS HEIGHT (=2.5*GD)
C      STEEP = PREDICTED RIPPLE STEEPNESS

C INITIALIZING PARAMETERS
      S=RHOS/RHOW
      SST=GD*((S-1)*G*GD)**0.5/(4*VISK)
      PSICR=(USTCRB**2)/((S-1)*G*GD)
      PSIBF=1.8*(SST**0.6)*PSICR
      USTBF=(PSIBF*(S-1)*G*GD)**0.5

C-----------------------------------------------------------------
C  FOR COARSE AND VERY-COARSE SANDS, BEDFORM GEOMETY CANNOT BE PREDICTED
C  AND THE INITIAL RIPPLE HEIGHT AND LENGTH WILL BE USED
      IF(GD .GE. 0.0005) THEN
           RHEIGHT=RHINP
           RLENGTH=RLINP
           IF (RLENGTH .EQ. 0) STEEP = 0
           IF (RLENGTH .GT. 0) STEEP=RHEIGHT/RLENGTH
           GO TO 33
      ENDIF

C-----------------------------------------------------------------
C  COMPUTE THE INITIAL RIPPLE CONVERSION COEFFICIENT RPLCOEF. IT IS EQUAL
C  TO 1 FOR FLAT BED, OTHERWISE IS CALCULATED ACCORDING TO NIELSEN (1992)
      IF(RHINP .EQ. 0 .OR. USTCWS .GE. USTUP) THEN
           RPLCOEF=1
      ELSE
           RPLCOEF=1/(1-3.14*RHINP/RLINP)
      ENDIF

C  COMPUTE EFFECTIVE SHEAR VELOCITY AT THE RIPPLE CREST
      USTCWSE=USTCWS*RPLCOEF

C-----------------------------------------------------------------
C  FOR NO TRANSPORT CASE, USE THE COMBINED WAVE-CURRENT RIPPLE HEIGHT AND
C  LENGTH AT THE BEDLOAD THRESHOLD CONDITION BASED ON LI AND AMOS (IN REVIEW)
C      IF(USTCWSE .LT. USTCRB) THEN
C           STEEP=0.12
C           RHEIGHT=GD*(22.15+6.38)
C           RLENGTH=RHEIGHT/STEEP
C           GO TO 33
C      ENDIF

C----------------------------------------------------------------- !ggu check
C  USE THE INITIAL RIPPLE HEIGHT AND LENGTH FOR NO TRANSPORT CASE  !ggu Li96
       IF(USTCWSE .LT. USTCRB) THEN
            RHEIGHT=RHINP
            RLENGTH=RLINP
            IF (RLENGTH .EQ. 0) STEEP = 0
            IF (RLENGTH .GT. 0) STEEP=RHEIGHT/RLENGTH
            GO TO 33
       ENDIF

C-----------------------------------------------------------------
C  COMPUTE RIPPLES FOR ACTIVE TRANSPORT CASE

C  RIPPLES IN THE WEAK-TRANSPORT RANGE
      IF(USTCWSE .GE. USTCRB .AND. USTCWS .LT. USTCRB) THEN
           STEEP=0.11
           RHEIGHT=GD*(19.59*(USTCWS/USTCRB)+20.92)
           RLENGTH=RHEIGHT/STEEP
      ENDIF

C  RIPPLES IN THE EQUILIBRIUM RANGE
      IF(USTCWS .GE. USTCRB .AND. USTCWS .LT. USTBF) THEN
C  COMPUTE WAVE-DOMINANT RIPPLES FOR U*WS/U*CS>=1.25
           IF(USTWS/USTCS .GE. 1.25) THEN
                STEEP=0.15
c                RHEIGHT=GD*(9.86*(USTCWS/USTCRB)+37.91)
                RHEIGHT=GD*(27.14*(USTCWS/USTCRB)+16.36)
           ELSE
C  COMPUTE COMBINED WAVE-CURRENT OR CURRENT-DOMINANT RIPPLES
                STEEP=0.12
                RHEIGHT=GD*(22.15*(USTCWS/USTCRB)+6.38)
           ENDIF
           RLENGTH=RHEIGHT/STEEP
      ENDIF

C  COMPUTE RIPPLES IN THE BREAK-OFF RANGE BASED ON THE SIB METHOD
      IF(USTCWS .GE. USTBF .AND. USTCWS .LT. USTUP) THEN
             RLENGTH = 530*GD
             STEEP=(0.15/(1-USTBF/USTUP))*(1-USTCWS/USTUP)
             RHEIGHT = RLENGTH*STEEP
      ENDIF

C  NO RIPPLES UNDER SHEET FLOW CONDITIONS
      IF (USTCWS .GE. USTUP) THEN
           RHEIGHT=0
           RLENGTH=0
           STEEP=0
      ENDIF

 33   CONTINUE

C  COMPUTE THE TRUE RIPPLE CONVERSION COEFFICIENT RPLCOEF
      IF(RHEIGHT .EQ. 0 .OR. RLENGTH .EQ. 0) THEN
           RPLCOEF=1
      ELSE
           RPLCOEF=1/(1-3.14*RHEIGHT/RLENGTH)
      ENDIF

C ************************************
C THE NEXT LINE IS ONLY RUN FOR SIB82 DATA TO CALCULATE RPLCOEF USING
C INPUT RIPPLE HEIGHT AND LENGTH
C      RPLCOEF=1/(1-3.14*RHINP/RLINP)

C  COMPUTE EFFECTIVE SHEAR VELOCITY AT THE RIPPLE CREST
      USTCWSE=USTCWS*RPLCOEF

C  CALCULATE BEDLOAD LAYER HEIGHT HTM USING THE MODIFIED NIELSEN
C  (1992) METHOD
      IF(USTCWS .GE. USTCRB) THEN
           HTM=2.9*GD*((USTCWS**2)/((S-1)*G*GD)-PSICR)**0.75
C  LIMIT HTM TO BE <10*GRAIN DIAMETER
           IF (HTM .GT. 10*GD) HTM=10*GD
C  CALCULATE BEDLOAD LAYER HEIGHT HTM USING THE MODIFIED GM82 METHOD
C           HTM=1.22*GD*(S+0.5)*PSICR*(USTCWS/USTCRB-0.7)**2
C      ELSE IF(USTCWSE .GE. USTCRB) THEN
C           HTM=1.22*GD*(S+0.5)*PSICR*((USTCRB/USTCWS)**(0.282)*
C     @         USTCWS/USTCRB-0.7)**2

      ELSE
           HTM=0
      ENDIF

C  COMPUTE VARIOUS ROUGHNESS HEIGHTS: RKB, RIPPLE ROUGHNESS HEIGHT
C  AND TKB, TOTAL BED ROUGHNESS HEIGHT.
      RKB=27.7*RHEIGHT*STEEP
      TKB=RKB+SKB

      RETURN
      END

C***********************************************************************
C*******************************************************************
C SUBROUTINE TIMIMG
C*******************************************************************

      SUBROUTINE TIMING(RHOW,UA,UB,PER,U100,USTCRB,USTCRS,USTCWS)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INCLUDE "sed_param.h"

C  TIMING2.FOR USES EFFECTIVE SHEAR STRESSES:
C      CASE 0 - AVERAGE SHEAR STRESS (LINE 92)                   NO
C      CASE A - EFFECTIVE SHEAR STRESSES (LINE 102)             YES
C      CASE B - MAXIMIZED EFFECTIVE SHEAR STRESSES (LINE 114)    NO
C
C  THIS SUBROUTINE USES EFFECTIVE SHEAR STRESSES AT RIPPLE CREST TO
C  CALCULATE THE DURATION OF SEDIMENT TRANSPORT PHASES (NO TRANSPORT, BEDLOAD
C  TRANSPORT, SUSPENDED LOAD TRANSPORT) BY CALCULATING WHEN THE RESPECTIVE
C  CRITICAL SHEAR STRESSES ARE EXCEEDED.
C  ** BEDLOAD USTCWSB IS 'NOT' USED IN DETERMINING TIME FOR SUSPENDED LOAD
C  TRANSPORT
C
C INPUT VARIABLES:
C       PER = WAVE PERIOD (SEC)
C      PHIB = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS WITHIN THE
C             WAVE BOUNDARY LAYER (RADIANS)
C   RPLCOEF = RIPPLE COEFFICIENT FOR SHEAR VELOCITY CONVERSION
C        UA = CURRENT SPEED TO BE USED IN BOTTOM STRESS CALC. (M/SEC)
C        UB = MAXIMUM WAVE-INDUCED BOTTOM PARTICLE VELOCITY (M/SEC)
C    USTCRB = CRITICAL FLUID VELOCITY FOR INITIATION OF BEDLOAD
C             TRANSPORT (M/SEC)
C    USTCRS = CRITICAL FLUID VELOCITY FOR INITIATION OF SUSPENDED
C             LOAD TRANSPORT (M/SEC)
C   USTCS = CURRENT SKIN-FRICTION SHEAR VELOCITY OF GM
C   USTWS = WAVE SKIN-FRICTION SHEAR VELOCITY OF GM
C  USTCWS = COMBINED SKIN-FRICTION SHEAR VELOCITY OF GM
C
C  OUTPUT VARIABLES:
C    PERBED = PERCENTAGE OF TIME SPENT IN ONLY BEDLOAD TRANSPORT PHASE.
C   PERSUSP = PERCENTAGE OF TIME SPENT IN SUSPENDED LOAD TRANSPORT PHASE.
C       TS1 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH SUSPENDED
C             LOAD TRANSPORT CEASES (SEC)
C       TB1 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH BEDLOAD
C             TRANSPORT CEASES (SEC)
C       TS2 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH SUSPENDED
C             LOAD TRANSPORT RECOMMENCES (SEC)
C       TB2 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH BEDLOAD
C             TRANSPORT RECOMMENCES (SEC)
C     USTCS = MAXIMUM CURRENT SKIN-FRICTION SHEAR VELOCITY
C     USTWS = GM WAVE SKIN-FRICTION SHEAR VELOCITY
C    USTCWS = GM WAVE-CURRENT SKIN-FRICTION SHEAR VELOCITY
C   USTCWSE = RIPPLE-ENHANCED EFFECTIVE SKIN-FRICTION SHEAR VELOCITY
C
C  INTERMEDIATE VARIABLES:
C    USTCSE = RIPPLE-ENHANCED EFFECTIVE CURRENT SKIN-FRICTION SHEAR VELOCITY
C    USTWSE = RIPPLE-ENHANCED EFFECTIVE WAVE SKIN-FRICTION SHEAR VELOCITY
C       XS1 = B+SQRT(B24ACS) USED IN SUSPENDED TIME CALCULATION UNDER CREST
C       XB1 = B+SQRT(B24ACB) USED IN BEDLOAD TIME CALCULATION UNDER CREST
C       XS2 = B-SQRT(B24ACS) USED IN SUSPENDED TIME CALCULATION UNDER TROUGH
C       XB2 = B-SQRT(B24ACB) USED IN BEDLOAD TIME CALCULATION UNDER TROUGH
C         B = -B/2A, AS IN EQ'N. FOR ROOTS OF A QUADRATIC EQUATION
C     B24AC = (B**2-4*A*C)/(2*A)**2, AS IN QUADRATIC EQ'N. SOLUTION

C  FIRST, SET DEFAULT VALUES
      TS1=0.0
      TB1=0.0
      TS2=0.0
      TB2=0.0
      PERSUSP=0.0
      PERBED=0.0

C*****************************
C PURE CURRENT CASE
C*****************************
      IF (UB .LT. 0.01) THEN
        IF (USTCS .GE. USTCRS) PERSUSP=100
        IF (USTCS .GE. USTCRB .AND. USTCS .LT. USTCRS) PERBED=100
        RETURN
      ENDIF

C*****************************
C WAVE PRESENT CASE
C*****************************
C --- CASE 0: NO (USE AVERAGE SHEAR STRESS)
C OBTAIN GRANT-MADSEN SKIN-FRICTION CURRENT SHEAR VELOCITY
C      USTCSE=USTCS
C OBTAIN SKIN-FRICTION WAVE SHEAR VELOCITY
C      USTWSE=USTWS
C OBTAIN SKIN-FRICTION COMBINED SHEAR VELOCITY
C      USTCWSE=USTCWS
C ASIGN THE COMBINED SHEAR VELOCITY TO THE MAXIMUM SHEAR VELOCITY
C      USTCWSM=USTCWSE

C --- CASE A: YES (USE RIPPLE-ENHANCED AVEARGE SHEAR STRESSES)
C COMPUTE RIPPLE-ENHANCED EFFECTIVE SKIN-FRICTION CURRENT SHEAR VELOCITY
      USTCSE=USTCS*RPLCOEF
C COMPUTE EFFECTIVE SKIN-FRICTION WAVE SHEAR VELOCITY
      IF (UB .NE. 0.0) USTWSE=USTWS*RPLCOEF
C COMPUTE THE EFFECTIVE SKIN-FRICTION COMBINED SHEAR VELOCITY
      USTCWSE=USTCWS*RPLCOEF
C ASIGN EFFECTIVE COMBINED SHEAR VELOCITY TO THE MAXIMUM SHEAR VELOCITY
c      USTCWSM=USTCWSE

C --- CASE B: NO (USE MAXIMIZED SHEAR STRESSES FOR CURRENT DOMINANT
C                 OR WAVE-CURRENT COMBINED CONDITIONS)
C      IF (USTWS/USTCS .LT. 1.25) THEN
C CHOOSE THE BIGGER FROM THE GM AND STERNBERG CURRENT SHEAR VELOCITIES
C      IF (USTCS .LT. USTCS1) USTCS=USTCS1
C          TAOCS=RHOW*USTCS**2
C          TAOWS=RHOW*USTWS**2
C COMPUTE VECTORIALLY THE MAXIMIZED COMBINED SKIN-FRICTION SHEAR STRESS BASED
C ON THE GM TAOWS AND MAXIMIZED TAOCS
C          TAOCWS=SQRT((TAOCS*SIN(PHIB))**2+
C     @            (TAOCS*COS(PHIB)+TAOWS)**2)
C          USTCWS=SQRT(TAOCWS/RHOW)
C      ENDIF
C COMPUTE RIPPLE-ENHANCED EFFECTIVE SKIN-FRICTION CURRENT SHEAR VELOCITY
C      USTCSE=USTCS*RPLCOEF
C COMPUTE EFFECTIVE SKIN-FRICTION WAVE SHEAR VELOCITY
C      IF (UB .NE. 0.0) USTWSE=USTWS*RPLCOEF
C COMPUTE THE EFFECTIVE SKIN-FRICTION COMBINED SHEAR VELOCITY
C      USTCWSE=USTCWS*RPLCOEF
C ASIGN EFFECTIVE COMBINED SHEAR VELOCITY TO THE MAXIMUM SHEAR VELOCITY
C      USTCWSM=USTCWSE

C-------------------------
C FOR WAVE-ONLY CONDITION
C-------------------------
      IF (UA .EQ. 0.0) THEN
C COVERT RIPPLE-ENHANCED SHEAR VELOCITIES TO SHEAR STRESSES
         TAOWS=RHOW*USTWSE**2
         TAOCRB=RHOW*USTCRB**2
         TAOCRS=RHOW*USTCRS**2
C CHECK IF SAND SUSPENSION OCCURS
         IF (USTCRS .LT. USTWSE) THEN
            TS1=PER/(2.*PII)*ACOS(TAOCRS/TAOWS)
            TS2=PER/2.-TS1
            PERSUSP=400.*TS1/PER
         ENDIF
C CHECK IF ONLY BEDLOAD TRANSPORT OCCURS AT TIMES
         IF (USTCRB .LT. USTCRS .AND. USTCRB .LT. USTWSE) THEN
            TB1=PER/(2.*PII)*ACOS(TAOCRB/TAOWS)
            TB2=PER/2.-TB1
            PERBED=400.*(TB1-TS1)/PER
         ENDIF
         RETURN
      ENDIF

C----------------------------------------
C CONSIDER COMBINED WAVES AND CURRENTS.
C----------------------------------------
C COVERT RIPPLE-ENHANCED SHEAR VELOCITIES TO SHEAR STRESSES
      TAOCS=RHOW*USTCSE**2
      TAOWS=RHOW*USTWSE**2
      TAOCRB=RHOW*USTCRB**2
      TAOCRS=RHOW*USTCRS**2

C*** FIRST CALCULATE TIMES FOR SUSPENDED LOAD ***
      IF (USTCWSE .LT. USTCRS) THEN
         PERSUSP=0
         GO TO 50
      ENDIF
      B24ACS=(TAOCRS**2.0-(TAOCS*SIN(PHIB))**2.0)/(TAOWS**2.0)
      IF (B24ACS .LE. 0.0) THEN
C CRITICAL STRESS FOR SUSPENSION OF SEDIMENT ALWAYS EXCEEDED
         TS1=PER/2.
         PERSUSP=100.0
         PERBED=0.0
         RETURN
      ENDIF
      B=-TAOCS*COS(PHIB)/TAOWS
      XS1=B+SQRT(B24ACS)
      IF (XS1 .GE. 1.0) THEN
C CRITICAL STRESS FOR SUSPENSION OF SEDIMENT NEVER EXCEEDED
         PERSUSP=0.0
         GO TO 50
      ENDIF
      IF (XS1 .LE. -1.0) THEN
C SECOND CASE WHERE CRITICAL STRESS FOR SUSPENSION OF SEDIMENT IS
C ALWAYS EXCEEDED
         TS1=PER/2.
         PERSUSP=100.0
         PERBED=0.0
         RETURN
      ELSE
C CRITICAL STRESS FOR SUSPENSION OF SEDIMENT SOMETIMES EXCEEDED
         TS1=PER/(2.*PII)*ACOS(XS1)
      ENDIF
      XS2=B-SQRT(B24ACS)
      IF (XS2 .LE. -1.0) THEN
C CRITICAL STRESS FOR SUSPENSION OF SEDIMENT NOT EXCEEDED DURING TROUGH
         PERSUSP=200.*TS1/PER
      ELSE
C CRITICAL STRESS FOR SUSPENSION OF SEDIMENT EXCEEDED DURING TROUGH
         TS2=PER/(2.*PII)*ACOS(XS2)
         PERSUSP=(2.*(TS1-TS2)+PER)/PER*100.
      ENDIF

C**** CALCULATE TIMES FOR BEDLOAD ****
C CALCULATE TIMES FOR BEDLOAD ONLY IF USTCRB < USTCRS
  50  IF (USTCRB .GE. USTCRS ) RETURN

C FOR EFFECTIVE SHEAR VELOCITY < USTCRB, NO BEDLOAD TRANSPORT
      IF (USTCWSE .LT. USTCRB) THEN
         PERBED=0
         RETURN
      ENDIF
      B24ACB=(TAOCRB**2-(TAOCS*SIN(PHIB))**2)/(TAOWS**2)
      IF (B24ACB .LE. 0.0) THEN
C CRITICAL STRESS FOR BEDLOAD TRANSPORT ALWAYS EXCEEDED
         TB1=PER/2.
         PERBED=100.-PERSUSP
         RETURN
      ENDIF
      B=-TAOCS*COS(PHIB)/TAOWS
      XB1=B+SQRT(B24ACB)
      IF (XB1 .GE. 1.0) THEN
C CRITICAL STRESS FOR BEDLOAD TRANSPORT NEVER EXCEEDED
         PERBED=0.0
         RETURN
      ENDIF

      IF (XB1 .LE. -1.0) THEN
C SECOND CASE WHERE CRITICAL STRESS FOR BEDLOAD TRANSPORT
C                                       IS ALWAYS EXCEEDED.
          TB1=PER/2.
          PERBED=100.-PERSUSP
          RETURN
      ENDIF

C CRITICAL STRESS FOR BEDLOAD TRANSPORT EXCEEDED DURING CREST
      TB1=PER/(2.*PII)*ACOS(XB1)
      XB2=B-SQRT(B24ACB)
      IF (XB2 .LE. -1.0) THEN
C CRITICAL STRESS FOR BEDLOAD TRANSPORT NOT EXCEEDED DURING TROUGH
         PERBED=200.*TB1/PER-PERSUSP
      ELSE
C CRITICAL STRESS FOR BEDLOAD TRANSPORT EXCEEDED DURING TROUGH
         TB2=PER/(2.*PII)*ACOS(XB2)
         PERBED=(2.*(TB1-TB2)+PER)/PER*100.-PERSUSP
      ENDIF

      RETURN
      END

C ****************************************************************
C SUBROUTINE PROFL
C ****************************************************************

      SUBROUTINE PROFL(D,RHOW,FALL,UB,CDIR,USTCWS,USTCW,USTCRB,USTCRS,
     @USTUP,Z0,QS,QSDIR,C0A)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INCLUDE "sed_param.h"

C THIS SUBROUTINE PREDICTS THE VELOCITY AND SUSPENDED SEDIMENT CONCENTRATION
C (SSC)PROFILES BASED ON THE GM86 COMBINED-FLOW BBL MODEL AND THE MODIFIED
C ROUSE EQUATION ACCORDING TO GLENN AND GRANT (1987).THE CALCULATED SSC AND
C VELOCITY PROFILES ARE THEN NUMERICALLY INTEGRATED TO OBTAIN THE SUSPENDED
C TRANSPORT RATE.
C
C INPUT VARIABLES:
C
C  D = WATER DEPTH (M)
C  CDIR = CURRENT DIRECTION
C  DELTACW = HEIGHT OF THE WAVE-CURRENT BOUNDARY LAYER
C  FALL = SAND SETTLING VELOCITY
C  RHOW = FLUID DENSITY
C  UB = WAVE ORBITAL VELOCITY
C  USTC = TOTAL CURRENT SHEAR VELOCITY
C  USTCRB = CRITICAL FLUID VELOCITY FOR INITIATION OF BEDLOAD TRANSPORT (M/S)
C  USTCRS = CRITICAL FLUID VELOCITY FOR INITIATION OF SUSPENDED LOAD TRANSPORT (M/S)
C  USTCS = SKIN-FRICTION CURRENT SHEAR VELOCITY
C  USTCW = TOTAL COMBINED WAVE AND CURRENT SHEAR VELOCITY
C  USTCWS = SKIN-FRICTION COMBINED SHEAR VELOCITY
C  USTCWSB = BEDLOAD COMBINED SHEAR VELOCITY
C  USTUP = CRITICAL FLUID VELOCITY FOR SHEET FLOW TRANSPORT (M/SEC)
C  USTW = TOTAL WAVE SHEAR VELOCITY
C  USTWS = SKIN-FRICTION WAVE SHEAR VELOCITY
C  Z0 = BED ROUGHNESS LENGTH (M)
C  Z0C = APPARENT BED ROUGHNESS LENGTH (M)
C
C OUTPUT VARIABLES:
C  C0 = REFERENCE CONCENTRATION AT Z0 (KG/M^3)
C  QS = SUSPENDED SEDIMENT TRANSPORT RATE (KG/M/S)
C  QSDIR = DIRECTION OF SUSPENDED SEDIMENT TRANSPORT (DEGREE)
C  C0A = DEPTH AVERAGED REFERENCE CONCENTRATION (KG/M^3)
C
C INTERMEDIATE VARIABLES:
C
C  CZ = PREDICTED SUSPENDED SEDIMENT CONCENTRATION AT HEIGHT Z (KG/M^3)
C  CZD = PREDICTED SUSPENDED SEDIMENT CONCENTRATION AT DELTACW (KG/M^3)
C  TAOST = NORMALIZED EXCESS SHEAR STRESS
C  UUZ = PREDICTED MEAN VELOCITY AT HEIGHT Z (M/S)
C  ZZ = HEIGHT ABOVE THE SEABED (M)
C  ZKAPPA = VON KARMAN CONSTANT (=0.4)
C  ZZINI = DEFAULT VALUES FOR ZZ

      DOUBLE PRECISION ZZINI(0:12)

C INITIALIZE ZZ, CZ AND UUZ
      DATA ZZINI /0.0,0.01,0.02,0.03,0.05,0.07,0.1,0.2,0.3,0.5,0.7,
     @1.0,2.0/

      DO 421,I=1,12
         ZZ(I)=ZZINI(I)
         CZ(I)=0
         UUZ(I)=0
421   CONTINUE

C GET THE UPPER LIMIT DEPTH FOR THE CONCENTRATION PROFILE
      IL = 12
      DO 12 I=1,IL
       IF (D.le.ZZ(I))THEN
        ZZ(I) = D
        IL = I
        GOTO 432
       END IF
 12    CONTINUE

432   CONTINUE

C SET DEFAULT VALUES TO ZERO
      C0=0
      CZD=0
      QS=0
      C0A=0
      SOM=0

C ASSIGN VALUES TO CONSTANTS
      ZKAPPA=0.4

C CONVERT SHEAR VELOCITIES TO SHEAR STRESSES
      TAOCS=RHOW*USTCS**2
      TAOWS=RHOW*USTWS**2
      TAOCWS=RHOW*USTCWS**2
      TAOCRB=RHOW*USTCRB**2

C*****************************
C COMPUTE THE VELOCITY PROFILE
C*****************************
C PURE WAVE CASE:
      IF (USTCS.EQ.0) GOTO 25
C PURE CURRENT CASE:
      IF (UB.LT.0.01) THEN
        DO 10 I=1,IL,1
        UUZ(I)=(USTC/ZKAPPA)*DLOG(ZZ(I)/Z0)    !al posto di ALOG
        IF (UUZ(I).LT.0.) UUZ(I)=0.
 10     CONTINUE                             !c'e' DLOG
      ELSE
C COMBINED WAVES AND CURRENT
        DO 20 I=1,IL,1
        IF (ZZ(I).LE.DELTACW) THEN
          UUZ(I)=(USTC/ZKAPPA)*(USTC/USTCW)*DLOG(ZZ(I)/Z0)
        ELSE
          UUZ(I)=(USTC/ZKAPPA)*DLOG(ZZ(I)/Z0C)
        ENDIF
        IF (UUZ(I).LT.0.) UUZ(I)=0.
 20     CONTINUE
      ENDIF

C*****************************************************
C COMPUTE THE SUSPENDED SEDIMENT CONCENTRATION PROFILE
C*****************************************************
 25   CONTINUE
C PURE CURRENT CASE:
      IF (UB.LT.0.01) THEN
        IF (USTCS.LT.USTCRS) THEN
          QS=0
          GOTO 300
        ELSE
C CALCULATE REFERENCE CONCENTRATIONS C0 AT Z0
          TAOST=(TAOCS-TAOCRB)/TAOCRB
          C0=GETC0(USTCS,USTUP,TAOST,USTBF)
          DO 40 I=1,IL
            CZ(I)=C0*(ZZ(I)/Z0)**(-0.74*FALL/(0.4*USTC))
            IF (CZ(I) .LT. 0.) CZ(I) = 0.
 40       CONTINUE
        ENDIF
      ELSE
        IF (USTCS.EQ.0) THEN
C PURE WAVE CASE:
          IF (USTWS.LT.USTCRS) THEN
            QS=0
            GOTO 300
          ELSE
C CALCULATE REFERENCE CONCENTRATIONS C0 AT Z0
            TAOST=(TAOWS-TAOCRB)/TAOCRB
            C0=GETC0(USTWS,USTUP,TAOST,USTBF)
            DO 60 I=1,IL
              CZ(I)=C0*(ZZ(I)/Z0)**(-0.74*FALL/(0.4*USTW))
              IF (CZ(I) .LT. 0.) CZ(I) = 0.
 60         CONTINUE
          ENDIF
        ELSE
C COMBINED WAVE-CURRENT CASE:
C FOR USTCWSB<USTCRS,NO SUSPENSION PROFILE WILL BE PREDICTED
          IF (USTCWSB.LT.USTCRS) THEN
            QS=0
            GOTO 300
          ELSE
C CALCULATE REFERENCE CONCENTRATIONS C0 AT Z0 AND CZD AT DELTACW
            TAOST=(TAOCWS-TAOCRB)/TAOCRB
            C0=GETC0(USTCWSB,USTUP,TAOST,USTBF)
            CZD=C0*(DELTACW/Z0)**(-0.74*FALL/(0.4*USTCW))
C PREDICT SUSPENSION PROFILE BASED ON THE MODIFIED ROUSE EQUATION
            DO 90 I=1,IL
              IF (ZZ(I).LE.DELTACW) THEN
                CZ(I)=C0*(ZZ(I)/Z0)**(-0.74*FALL/(0.4*USTCW))
              ELSE
                CZ(I)=CZD*(ZZ(I)/DELTACW)**(-0.74*FALL/(0.4*USTC))
              ENDIF
              IF (CZ(I) .LT. 0.) CZ(I) = 0.
 90         CONTINUE
          ENDIF
        ENDIF
      ENDIF

C*********************************************************************
C INTEGRATE VELOCITY AND SSC PROFILE FOR SUSPENDED LOAD TRNSPORT RATE
C AND CALCULATE THE DEPTH AVERAGED EQUILIBRIUM CONCENTRATION (C0A) 	!ccf
C*********************************************************************

      ZZ(0)=0
      DO 95 I=1,IL
        QS=QS+(ZZ(I)-ZZ(I-1))*UUZ(I)*CZ(I)
        SOM = SOM + CZ(I)*(ZZ(I)-ZZ(I-1))
 95   CONTINUE
      C0A = SOM/D

C ASSIGN THE CURRENT DIRECTION AS THE DIRECTION OF QS
      QSDIR=CDIR

 300  CONTINUE
      RETURN
      END

C ************************************************************
C FUNCTION GETC0
C This function compute the reference concentration C0 using
C Smith and McLean (1977).

      FUNCTION GETC0(UST,USTUP,TAOST,USTBF)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C     UST = SHEAR VELOCITY
C  GAMMA0 = SAND RESUSPENSION COEFFICIENT
C      CB = BULK BOTTOM SEDIMENT CONCENTRATION (KG/M^3)
C   USTBF = CRITICAL SHEAR VELOCITY FOR RIPPLE BREAKOFF

       CB=1722.5

C PREDICT GAMMA0 BASED ON LI ET AL.(IN 1996)
       IF (UST.LT.USTBF.OR.TAOST.LE.1.) THEN
         GAMMA0=0.0355*TAOST**1.94
       ELSEIF (UST.GE.USTBF.AND.UST.LT.USTUP) THEN
         GAMMA0=0.0206*TAOST**(-1.931)
       ELSE
         GAMMA0=0.00013
       ENDIF

       GETC0=CB*GAMMA0*TAOST

       END

C ************************************************************
C SUBROUTINE TRANSPO
C ************************************************************
      SUBROUTINE TRANSPO(D,UA,UB,U100,PER,GD,BETA,RHOS,RHOW,USTCRB,
     @VISK,FCW,USTCWS,HT,CDIR,WDIR,IOPT1,DX,FALL,SED,SEDM,SEDDIR)

      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INCLUDE "sed_param.h"

C  TRANSPO4.FOR USES EFFECTIVE COMBINED SHEAR STRESS FOR TRANSPORT
C  CALCULATION. THE TOTAL TRANSPORT DUE TO TAOCWS IS OBTAINED FIRST. THE
C  ORIGINAL COEFFICIENTS OF 0.005 AND M=0.635 ARE USED IN BAGNLOD AND YALIN
C  RESPECTIVELY. THE OPTIONS ARE:
C      CASE O: USING THE AVERAGE GM SHEAR STRESS             NO
C      CASE A: USING EFFECTIVE SHEAR STRESS TAOCWE           NO
C      CASE B: USING THE AVERAGE (TAOCR+TAOCWE)/2            NO
C      CASE C: USING 1.4*TAOCWS OF WIBERG-NELSON STRESS      NO
C      CASE D: USING NEW EFFECTIVE SHEAR STRESS              YES
C      CASE E: USING 1.65*TCWS OF WIBERG-NELSON              NO
C
C  THIS SUBROUTINE CALCULATES THE TIME-AVERAGED NET SEDIMENT TRANSPORT
C  BY A CHOICE OF METHODS.  FOR THE PURE WAVE CASE THERE IS NO NET
C  TRANSPORT SINCE TRANSPORT DURING THE WAVE CREST IS EQUAL AND OPPOSITE
C  TO THAT DURING THE WAVE TROUGH (DUE TO THE USE OF LINEAR WAVE THEORY).
C  FOR THE PURE CURRENT AND MIXED CONDITIONS, THE USER MAKES A CHOICE
C  BETWEEN TRANSPORT FORMULAE, HOWEVER IF SUSPENDED LOAD TRANSPORT IS
C  SIGNIFICANT IT IS RECOMMENDED THAT A TOTAL LOAD FORMULA BE USED.
C
C  THE OPTIONS AVAILABLE ARE:
C
C            1 - ENGELUND-HANSEN (1967) TOTAL LOAD EQUATION,
C            2 - EINSTEIN-BROWN (1950) BEDLOAD EQUATION,
C            3 - BAGNOLD (1963) TOTAL LOAD EQUATION,
C            4 - YALIN (1963) BEDLOAD EQUATION,
C            5 - VAN RIJN (1993) BEDLOAD EQUATION,
C
C   THE CHOICE IS CONTROLLED BE THE VALUE OF "IOPT1" (1 TO 7) WHICH
C   IS READ IN IN SUBROUTINE READIN (READBCH FOR THE BATCH PROGRAM)
C
C INPUT VARIABLES:
C       D = WATER DEPTH (M)                                          (INDATA96 file)
C     PER = WAVE PERIOD (SEC)                                        (INDATA96 file)
C      GD = SEDIMENT GRAIN SIZE (M)                                  (INDATA96 file)
C    BETA = BED SLOPE (DEGREE)                                       (INDATA96 file)
C    CDIR = CURRENT DIRECTION (AZIMUTH,DEGREES)                      (INDATA96 file)
C    WDIR = WAVE DIRECTION (AZIMUTH,DEGREES)                         (INDATA96 file)
C   IOPT1 = OPTION SELECTED FOR SEDIMENT TRANSPORT FORMULA           (INDATA96 file)
C   RKERO = PROPORT. COEFFICIENT FOR EROSION RATE (DEFAULT = 1.62)*  (INDATA96 file)
C    RHOS = SEDIMENT DENSITY (KG/M**3)                               (READIN subroutine)
C    RHOW = FLUID DENSITY (KG/M**3)                                  (READIN subroutine)
C      UB = MAXIMUM WAVE-INDUCED BOTTOM PARTICLE VELOCITY (M/SEC)    (OSCIL subroutine)
C  USTCRB = CRITICAL SHEAR VELOCITY FOR BEDLOAD TRANSPORT            (THRESH subroutine)
C      UA = CURRENT SPEED TO BE USED IN BOTTOM STRESS CALC (M/SEC)   (FRICFAC subroutine)
C    U100 = CURRENT SPEED AT 1 M. ABOVE SEABED (M/SEC)               (FRICFAC subroutine)
C    PHIB = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS WITHIN THE     (FRICFAC subroutine)
C           WAVE BOUNDARY LAYER (RADIANS)
C  PHI100 = ANGLE BETWEEN WAVE AND CURRENT DIRECTIONS AT 1 M.        (FRICFAC subroutine)
C           ABOVE SEABED (RADIANS)
C     FCW = BOTTOM FRICTION FACTOR                                   (FRICFAC subroutine)
C RPLCOEF = RIPPLE COEFFICIENT FOR SHEAR VELOCITY CONVERSION         (FRICFAC subroutine)
C   USTCS = MAXIMUM CURRENT SKIN-FRICTION SHEAR VELOCITY             (FRICFAC subroutine)
C   USTWS = GM WAVE SKIN-FRICTION SHEAR VELOCITY                     (FRICFAC subroutine)
C  USTCWS = GM COMBINED WAVE-CURRENT SKIN-FRICTION SHEAR VELOCITY    (FRICFAC subroutine)
C USTCWSB = TRANSPORT-RELATED COMBINED SHEAR VELOCITY                (FRICFAC subroutine)
C     TB1 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH BEDLOAD      (TIMING subroutine)
C           TRANSPORT CEASES (SEC)
C     TB2 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH BEDLOAD      (TIMING subroutine)
C           TRANSPORT RECOMMENCES (SEC)
C     TS1 = TIME, AFTER PASSAGE OF WAVE CREST, AT WHICH SUSPENDED    (TIMING subroutine)
C           LOAD TRANSPORT CEASES (SEC)
C  PERBED = PERCENTAGE OF TIME SPENT IN BEDLOAD TRANSPORT PHASE      (TIMING subroutine)
C PERSUSP = PERCENTAGE OF TIME SPENT IN SUSP. LOAD TRANSPORT PHASE   (TIMING subroutine)
C    VISK = KINEMATIC VISCOSITY OF FLUID (M**2/SEC)
C      DX = DIMENSIONLESS GRAIN SIZE
C    FALL = SPHERICAL-GRAIN SETTLING VELOCITY [M/S]
C      HT = WAVE HEIGHT (M)
C
C OUTPUT VARIABLES:
C     SED = TIME-AVERAGED NET SEDIMENT TRANSPORT AS VOLUME TRANSPORTED PER
C           UNIT BED WIDTH PER UNIT TIME (M**3/M/S)
C    SEDM = TIME-AVERAGED NET SEDIMENT TRANSPORT AS MASS OF SEDIMENT
C           SOLIDS TRANSPORTED PER UNIT BED WIDTH PER UNIT TIME (KG/M/S)
C  SEDDIR = DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)
C
C INTERMEDIATE VARIABLES:
C      G = GRAVITY ACCELERATION
C   DRHO = RHOS-RHOW
C DGAMMA = G*DRHO
C    PHI = ANGLE OF REPOSE : ESTIMATED TO BE 30
C      S = SPECIFIC GRAVITY OF WATER
C    VCB = CRITICAL FLUID VELOCITY FOR INITIATION OF BEDLOAD TRANSPORT
C     DS = DIFFERENCE BETWEEN SPECIFIC GRAVITY OF SEDIMENT AND WATER
C  TAOCS = SKINFRICTION CURRENT SHEAR STRESS
C  TAOWS = SKINFRICTION WAVE SHEAR STRESS

C----------------------------------------------
C INITIALIZE AND DEFINE CONSTANTS AND VARIABLES
C----------------------------------------------
      DRHO=RHOS-RHOW
      DGAMMA=G*DRHO
      PHI=30
      IF (PER .NE. 0.0) W=2.*PII/PER
      VCB=0.0                        !ggu INTEL
      SED=0.0
      SEDM=0.0
      SEDDIR=0.0
      RLWRT = 0.0
      TAO0 = 0.0

C CALCULATE BEDLOAD THRESHOLD FLOW VELOCITY VCB
      TAOCRB=RHOW*USTCRB**2
      VCB=SQRT(2.*TAOCRB/(RHOW*FCW))

C******************************
C  WAVES ONLY (NO NET CURRENT)
C******************************
C  FOR THE PURE WAVE CASE, NO NET TRANSPORT OCCURS. EXIT PROGRAM.
C      IF (UA .EQ. 0.0 .AND. IOPT1. NE. 7) RETURN

C******************************
C  CURRENT ONLY (NO WAVES)
C******************************
C  NO INTEGRATION IS REQUIRED FOR THE PURE CURRENT CASE.
C  WHEN TRANSPORT IS ALL IN SUSPENDED LOAD, THEN A WARNING MESSAGE
C  IS PRINTED CONCERNING THE USE OF "BEDLOAD" TRANSPORT PREDICTORS

C  SKIP THIS SECTION IF THERE ARE BOTH WAVES AND CURRENTS
      IF (UB .GT. 0.01) GOTO 888

C CHECK IF THERE IS ANY TRANSPORT, IF NOT THEN EXIT.
      IF (PERBED .EQ. 0.0 .AND. PERSUSP .EQ. 0.0) RETURN

C OBTAIN CURRENT SHEAR STRESS TAO0, UA=U100 FOR STEADY CURRENT
C      TAO0=RHOW*FCW/2.*UA**2
      TAO0=RHOW*USTCS**2

      GOTO 777

 888  CONTINUE

C******************************
C  COMBINED WAVE AND CURRENT
C******************************
C
C  THE COMBINED WAVE AND CURRENT CASE REQUIRES INTEGRATION OF THE
C  INSTANTANEOUS TRANSPORT OVER THE WAVE PERIOD. THE USE OF LWT ALLOWS
C  INTEGRATION TO BE DONE OVER ONLY HALF A WAVE CYCLE. BAGNOLD'S METHOD
C  DOES NOT REQUIRE INTEGRATION. THE X- AND Y- COMPONENTS OF TRANSPORT
C  ARE CONSIDERED SEPARATELY, WHERE THE X-COMPONENT IS PARALLEL TO THE
C  WAVE DIRECTION AND THE Y-COMPONENT IS NORMAL TO THE WAVE DIRECTION.
C
C  INTERMEDIATE VARIABLES:
C      STEPC = INTEGRATION TIME STEP OF SEDIMENT TRANSPORT UNDER CREST
C      STEPT = INTEGRATION TIME STEP OF SEDIMENT TRANSPORT UNDER TROUGH
C      TIMEC = SEDIMENT TRANSPORT TIME UNDER CREST
C      TIMET = SEDIMENT TRANSPORT TIME UNDER TROUGH
C      RLWRT = LOWER LIMIT OF TRANSPORT INTEGRATION UNDER TROUGH

C  CHECK IF CRITICAL STRESS IS EVER EXCEEDED, IF NOT THEN EXIT.
      IF (TB1 .EQ. 0.0 .AND. TS1 .EQ. 0.0) RETURN
      IF (PERBED .EQ. 0.0 .AND. PERSUSP .EQ. 0.0) RETURN

C COMPUTE THE TRANSPORT TIMES FOR WAVE CREST AND TROUGH RESPECTIVELY
      IF (TB1 .EQ. PER/2. .OR. TS1 .EQ. PER/2.) THEN
         TIMEC = PER/4.
         TIMET = PER/4.
         RLWRT = PER/4.
      ELSE IF (TB1 .GT. 0. .AND. TB2 .GT. 0.) THEN
         TIMEC = TB1
         TIMET = PER/2. - TB2
         RLWRT = TB2
      ELSE
         TIMEC=TB1
         TIMET=0.
      ENDIF

C COMPUTE THE INTEGRATION TIME STEPS
      IF (TIMEC .GE. 10.) THEN
         NC = 20
      ELSE
         NC = 10
      ENDIF
      IF (TIMET .GE. 10.) THEN
         NT = 20
      ELSE
         NT = 10
      ENDIF
      STEPC = TIMEC/NC
      STEPT = TIMET/NT

 777  CONTINUE

C-----------------------------------
C DECIDE FORMULA ACCORDING TO IOPT1
C-----------------------------------

      GOTO (1,2,3,4,5) IOPT1

 1    CALL ENGHAN(RHOW,DGAMMA,GD,U100,USTCS,USTWS,USTCWS,USTCWSB,
     @PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,TIMET,STEPC,STEPT,
     @RLWRT,UB,TAO0,IOPT1,PER,PHI100,CDIR,WDIR,SED,SEDDIR)
      GOTO 998

 2    CALL EINBWN(RHOW,DGAMMA,GD,FALL,USTCS,USTWS,USTCWS,USTCWSB,
     @PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,TIMET,STEPC,STEPT,
     @RLWRT,UB,TAO0,IOPT1,PER,PHI100,CDIR,WDIR,SED,SEDDIR)
      GOTO 998

 3    CALL BAGNLD(RHOW,DGAMMA,U100,CDIR,USTCWS,USTCWSB,
     @USTCRB,USTBF,USTUP,RPLCOEF,SED,SEDDIR,UB,GD,RHOS,VCB)
      GOTO 998

 4    CALL YALIN(RHOW,RHOS,GD,USTCS,USTWS,USTCWS,USTCWSB,
     @PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,TIMET,STEPC,STEPT,
     @RLWRT,UB,FCW,UA,VCB,TAOCRB,G,DRHO,IOPT1,
     @PER,PHI100,CDIR,WDIR,SED,SEDDIR)
      GOTO 998

 5    CALL VANRIJN(RHOW,RHOS,HT,D,DX,GD,USTCS,USTWS,USTCWS,
     @USTCWSB,TAOCRB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,
     @TIMET,STEPC,STEPT,RLWRT,UB,TAO0,IOPT1,PER,PHI100,CDIR,WDIR,
     @SED,SEDDIR)
      GOTO 998

 998  CONTINUE

C INLUDE BED-SLOPE EFFECT AND THEN CONVERT SED FROM VOLUME FLUX (M^2/M/S)
C TO MASS FLUX SEDM IN KG/SEC/M.

      SED=SED*(1-TAN(BETA/57.3)/TAN(PHI/57.3))
      SEDM = RHOS*SED
      RETURN
      END

C****************************************************************************
C***********************************************************************

      SUBROUTINE ENGHAN(RHOW,DGAMMA,GD,U100,USTCS,USTWS,USTCWS,
     @USTCWSB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,TIMET,
     @STEPC,STEPT,RLWRT,UB,TAO0,IOPT1,PER,PHI100,CDIR,WDIR,SED,SEDDIR)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C THIS SUBROUTINE CALCULATES SEDIMENT TRANSPORT RATES ACCORDING TO
C THE ENGELUND AND HANSEN (1967) TOTAL LOAD EQUATION.
C
C OUTPUT VARIABLE:
C     SED = VOLUME RATE OF SEDIMENT TRANSPORT PER UNIT WIDTH OF BED
C  SEDDIR = DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)

C  SKIP THIS SECTION IF THERE ARE BOTH WAVES AND CURRENTS
      IF (UB .GT. 0.01) GOTO 123

C****************************
C  CURRENT ONLY (NO WAVES)
C****************************

      V=U100
      SED=0.05*V**2*SQRT(TAO0**3*RHOW)/(GD*DGAMMA**2)
      SEDDIR=CDIR
      RETURN

 123  CONTINUE

C*****************************
C  COMBINED WAVE AND CURRENT
C*****************************

      CONST1=0.05*(RHOW*U100/DGAMMA)**2/GD
      CONST2=3.

      CALL WAVEINT(IOPT1,CONST1,CONST2,RHOW,USTCS,USTWS,USTCWS,
     @USTCWSB,TAOCRB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,
     @TIMET,STEPC,STEPT,RLWRT,PER,PHI100,CDIR,WDIR,SED,SEDDIR)

      RETURN
      END

C*********************************************************************
C***********************************************************************

      SUBROUTINE EINBWN(RHOW,DGAMMA,GD,FALL,USTCS,USTWS,USTCWS,
     @USTCWSB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,TIMET,
     @STEPC,STEPT,RLWRT,UB,TAO0,IOPT1,PER,PHI100,CDIR,WDIR,SED,SEDDIR)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C THIS SUBROUTINE CALCULATES SEDIMENT TRANSPORT RATES ACCORDING TO
C THE EINSTEIN AND BROWN (1950) BEDLOAD EQUATION.
C
C OUTPUT VARIABLE:
C     SED = VOLUME RATE OF SEDIMENT TRANSPORT PER UNIT WIDTH OF BED
C  SEDDIR = DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)

C  SKIP THIS SECTION IF THERE ARE BOTH WAVES AND CURRENTS
      IF (UB .GT. 0.01) GOTO 123

C****************************
C  CURRENT ONLY (NO WAVES)
C****************************

      SED = 40.0*FALL*GD*(TAO0/(DGAMMA*GD))**3
      SEDDIR=CDIR
      RETURN

 123  CONTINUE

C*****************************
C  COMBINED WAVE AND CURRENT
C*****************************

      CONST1=40*FALL*GD*(RHOW/(GD*DGAMMA))**3
      CONST2=6.

      CALL WAVEINT(IOPT1,CONST1,CONST2,RHOW,USTCS,USTWS,USTCWS,
     @USTCWSB,TAOCRB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,
     @TIMET,STEPC,STEPT,RLWRT,PER,PHI100,CDIR,WDIR,SED,SEDDIR)

      RETURN
      END

C*********************************************************************
C*********************************************************************

      SUBROUTINE BAGNLD(RHOW,DGAMMA,U100,CDIR,USTCWS,USTCWSB,
     @USTCRB,USTBF,USTUP,RPLCOEF,SED,SEDDIR,UB,GD,RHOS,VCB)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C THIS SUBROUTINE CALCULATES SEDIMENT TRANSPORT RATES ACCORDING TO
C THE BAGNOLD (1963) TOTAL LOAD EQUATION.
C
C OUTPUT VARIABLE:
C     SED = VOLUME RATE OF SEDIMENT TRANSPORT PER UNIT WIDTH OF BED
C  SEDDIR = DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)

C  SKIP THIS SECTION IF THERE ARE BOTH WAVES AND CURRENTS
      IF (UB .GT. 0.01) GOTO 123

C****************************
C  CURRENT ONLY (NO WAVES)
C****************************

      BETA=1.73D0
      IF (GD .LE. 0.00031) BETA=7.22D0
      SED=BETA/RHOS*(U100-VCB)**3
      SEDDIR=CDIR
      RETURN

 123  CONTINUE

C*****************************
C  COMBINED WAVE AND CURRENT
C*****************************

      USTCWSGM=USTCWS
      ALPHA=(USTUP-USTCWSB)/(USTUP-USTBF)
C COMPUTE EFFECTIVE SHEAR VELOCITY AT THE RIPPLE CREST
      USTCWSE=USTCWS*RPLCOEF
C CONVERT SHEAR VELOCITIES TO SHEAR STRESSES
      TAOCRB = RHOW*USTCRB**2
      TAOCWS = RHOW*USTCWS**2
      TAOCWSE = RHOW*USTCWSE**2

C COMPUTE THE EFFECTIVE SHEAR STRESS CAUSING SEDIMENT TRANSPORT
C -----------------------------------------
C CASE O: NO
C USING THE AVERAGE GM SHEAR STRESS
C      TAOCWS=TAOCWS
C -----------------------------------------
C -----------------------------------------
C CASE A: NO
C USING THE RIPPLE-ENHANCED SHEAR STRESS
C      TAOCWS=TAOCWSE
C -----------------------------------------
C -----------------------------------------
C CASE B: NO
C USING THE AVERAGE SHEAR STRESS OF TAOCRB AND TAOCWSE
C      TAOCWS = 0.5*(TAOCRB+TAOCWSE)
C -----------------------------------------
C -------------------------------------------
C CASE D: YES
C USING THE NEW EFFECTIVE SHEAR STRESS

C FOR WEAK-TRANSPORT RIPPLES
      IF (USTCWSGM .LT. USTCRB) THEN
         TAOCWS=0.5*(TAOCRB+TAOCWSE)
      ENDIF

C FOR EQUILIBRIUM RIPPLES
      IF (USTCWSB .GE. USTCRB .AND. USTCWSB .LT. USTBF) THEN
C CHOICE A: USE (TAOCRB+TAOCWS+TAOCWSE)/3 FOR USTCWSB<USTBF
C         TAOCWS=0.333*(TAOCRB+TAOCWS+TAOCWSE)
C CHOICE B: USE (TAOCRB+TAOCWSE)/2 FOR USTCWSB<USTBF
         TAOCWS=0.5*(TAOCRB+TAOCWSE)
      ENDIF

C FOR BREAK-OFF RIPPLES
      IF (USTCWSB .GE. USTBF .AND. USTCWSB .LT. USTUP) THEN
         TAOCWS=(1/(2+ALPHA))*(ALPHA*TAOCRB+TAOCWS+TAOCWSE)
      ENDIF

C FOR UPPER-PLANE BED
      IF (USTCWSB .GE. USTUP) TAOCWS=TAOCWS
C -------------------------------------------

C COMPUTE NORMALIZED EXCESS SHEAR STRESS EST
      EST = (TAOCWS - TAOCRB)/TAOCRB

C CALCULATE TOTAL TRANSPORT RATE; RK IS BASED ON STERNBERG (1972)
        IF (EST .LT. 0) THEN
           SED = 0
        ELSE
           RK = 0.005*EXP(0.7*EST)
           SED=RK*TAOCWS*U100/DGAMMA
        ENDIF
        SEDDIR=CDIR
      RETURN
      END

C*********************************************************************
C*********************************************************************

      SUBROUTINE YALIN(RHOW,RHOS,GD,USTCS,USTWS,USTCWS,
     @USTCWSB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,TIMET,
     @STEPC,STEPT,RLWRT,UB,FCW,UA,VCB,TAOCRB,G,DRHO,IOPT1,
     @PER,PHI100,CDIR,WDIR,SED,SEDDIR)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

C THIS SUBROUTINE CALCULATES SEDIMENT TRANSPORT RATES ACCORDING TO
C THE YALIN (1963) BEDLOAD EQUATION.
C
C OUTPUT VARIABLE:
C     SED = VOLUME RATE OF SEDIMENT TRANSPORT PER UNIT WIDTH OF BED
C  SEDDIR = DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)

C  SKIP THIS SECTION IF THERE ARE BOTH WAVES AND CURRENTS
      IF (UB .GT. 0.01) GOTO 123

C****************************
C  CURRENT ONLY (NO WAVES)
C****************************

      USTAR=SQRT(FCW/2.)*UA
      S=(UA/VCB)**2-1.0
      A=2.45*(RHOW/RHOS)**0.4*SQRT(TAOCRB/(G*DRHO*GD))
      SED=0.635*GD*USTAR*S*(1.0-DLOG(1.0+A*S)/(A*S))
      SEDDIR=CDIR
      RETURN

 123  CONTINUE

C*****************************
C  COMBINED WAVE AND CURRENT
C*****************************

      CONST1=0.635*GD
      CONST2=2.45*(RHOW/RHOS)**0.4*SQRT(TAOCRB/(G*DRHO*GD))

      CALL WAVEINT(IOPT1,CONST1,CONST2,RHOW,USTCS,USTWS,USTCWS,
     @USTCWSB,TAOCRB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,
     @TIMET,STEPC,STEPT,RLWRT,PER,PHI100,CDIR,WDIR,SED,SEDDIR)

      RETURN
      END

C*********************************************************************
C*********************************************************************

      SUBROUTINE VANRIJN(RHOW,RHOS,HT,D,DX,GD,USTCS,USTWS,USTCWS,
     @USTCWSB,TAOCRB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,
     @TIMET,STEPC,STEPT,RLWRT,UB,TAO0,IOPT1,PER,PHI100,CDIR,WDIR,
     @SED,SEDDIR)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      COMMON /MCONST/ G,PII
      SAVE /MCONST/

C THIS SUBROUTINE CALCULATES SEDIMENT TRANSPORT RATES ACCORDING TO
C THE VAN RIJN (1993) BEDLOAD EQUATION
C
C OUTPUT VARIABLE:
C     SED = VOLUME RATE OF SEDIMENT TRANSPORT PER UNIT WIDTH OF BED
C  SEDDIR = DIRECTION OF NET SEDIMENT TRANSPORT (AZIMUTH,DEGREES)
C
C INTERMEDIATE VARIABLE:
C     S = INSTANTANEOUS SHEAR STRESS PARAMETER [ADIMENSIONAL]
C     A = CALIBRATION FACTOR

C  SKIP THIS SECTION IF THERE ARE BOTH WAVES AND CURRENTS
      IF (UB .GT. 0.01) GOTO 123

C****************************
C  CURRENT ONLY (NO WAVES)
C****************************

      F = RHOS/RHOW
      F1 = F - 1.
      S = TAO0/TAOCRB - 1.
      IF (S .LT. 3) THEN
        EEXP = 2.1
      ELSE
        EEXP = 1.5
      END IF

      SED = 0.053*(F1*G)**0.5 * GD**1.5 * DX**(-0.3) * S**EEXP
      SEDDIR=CDIR
      RETURN

 123  CONTINUE

C*****************************
C  COMBINED WAVE AND CURRENT
C*****************************

      A = 1. - (HT/D)**0.5
      CONST1=0.25*A*GD*DX**(-0.3)
      CONST2=1.

      CALL WAVEINT(IOPT1,CONST1,CONST2,RHOW,USTCS,USTWS,USTCWS,
     @USTCWSB,TAOCRB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,
     @TIMET,STEPC,STEPT,RLWRT,PER,PHI100,CDIR,WDIR,SED,SEDDIR)

      RETURN
      END

C*********************************************************************

      SUBROUTINE WAVEINT(IOPT1,CONST1,CONST2,RHOW,USTCS,USTWS,USTCWS,
     @USTCWSB,TAOCRB,PHIB,USTCRB,USTBF,USTUP,RPLCOEF,W,NC,NT,
     @TIMET,STEPC,STEPT,RLWRT,PER,PHI100,CDIR,WDIR,SED,SEDDIR)
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      COMMON /MCONST/ G,PII
      SAVE /MCONST/

C THIS SUBROUTINE COMPUTE THE TIME AVERAGED TRANSPORT (AS VOLUME)
C THROUGH THE INTEGRATION OVER A WAVE CYCLE
C
C  INTERMEDIATE VARIABLES:
C         S = INSTANTANEOUS SHEAR STRESS PARAMETER [ADIMENSIONAL]
C       GSXC = VOLUME TRANSPORT IN WAVE DIRECTION IN TIME STEPC
C       GSXT = VOLUME TRANSPORT IN WAVE DIRECTION IN TIME STEPT
C      SEDXC = TOTAL VOLUME TRANSPORT IN WAVE DIRECTION UNDER CREST
C      SEDXT = TOTAL VOLUME TRANSPORT IN WAVE DIRECTION UNDER TROUGH
C      SEDYC = TOTAL VOLUME TRANSPORT IN Y DIRECTION UNDER CREST
C      SEDYT = TOTAL VOLUME TRANSPORT IN Y DIRECTION UNDER TROUGH

      GSXC = 0.0
      GSXT = 0.0
      GSYC = 0.0
      GSYT = 0.0
      SEDXC= 0.0
      SEDYC= 0.0
      SEDXT= 0.0
      SEDYT= 0.0
      CONST3 = CONST2

C PRESERVE THE BURST-AVERAGED SHEAR VELOCITIES
      USTCSGM=USTCS
      USTWSGM=USTWS
      USTCWSGM=USTCWS
      ALPHA=(USTUP-USTCWSB)/(USTUP-USTBF)

C CONVERT SHEAR VELOCITIES TO SHEAR STRESSES
      TAOCRB=RHOW*USTCRB**2
      TAOCS=RHOW*USTCS**2
      TAOWS=RHOW*USTWS**2

C COMPUTE STEADY CURRENT SHEAR STRESS IN THE X DIRECTION
      TAOCSX=TAOCS*COS(PHIB)

C COMPUTE STEADY CURRENT SHEAR STRESS IN THE Y DIRECTION
      TAOCSY=TAOCS*SIN(PHIB)

C ===================================================================
C COMPUTE TRANSPORT VOLUME UNDER THE WAVE CREST
      DO 111 I = 0, (NC-1)
         TAOCWSX=TAOCSX+0.5*TAOWS*(COS(W*I*STEPC)+COS(W*(I+1)*STEPC))
         TAOCWS=SQRT(TAOCSY**2+TAOCWSX**2)
         TAOCWSE=(RPLCOEF**2)*TAOCWS

C -----------------------------------------
C CASE O: NO
C USING THE AVERAGE GM SHEAR STRESS
C         USTCWS=SQRT(TAOCWS/RHOW)
C -----------------------------------------
C -------------------------------------------
C CASE A: NO
C USING EFFECTIVE SHEAR STRESS
C         USTCWS=RPLCOEF*SQRT(TAOCWS/RHOW)
C -------------------------------------------
C -------------------------------------------
C CASE B: NO
C USING THE AVERAGED EFFECTIVE SHEAR STRESS OF TAOCRB AND TAOCWSE
C         TAOCWS=0.5*(TAOCRB+TAOCWSE)
C         USTCWS=SQRT(TAOCWS/RHOW)
C -----------------------------------------
C -----------------------------------------
C CASE C: NO OR CASE E: NO
C USING THE EFFECTIVE SHEAR STRESS OF WIBERG-NELSON (1992)
C
C FOR CASE C
C         IF (USTCWSB .LT. USTBF) TAOCWS=1.4*TAOCWS
C         IF (USTCWSB .GE. USTBF .AND. USTCWSB .LT. USTUP) THEN
C            TAOCWS=(1+0.4*ALPHA)*TAOCWS
C         ENDIF
C         IF (USTCWSB .GE. USTUP) TAOCWS=TAOCWS
C
C FOR CASE E
C         IF (USTCWSB .LT. USTBF) TAOCWS=1.65*TAOCWS
C         IF (USTCWSB .GE. USTBF .AND. USTCWSB .LT. USTUP) THEN
C            TAOCWS=(1+0.65*ALPHA)*TAOCWS
C         ENDIF
C         IF (USTCWSB .GE. USTUP) TAOCWS=TAOCWS
C
C         USTCWS=SQRT(TAOCWS/RHOW)
C -------------------------------------------
C -------------------------------------------
C CASE D: YES
C USING THE NEW EFFECTIVE SHEAR STRESS

C FOR WEAK-TRANSPORT RIPPLES
      IF (USTCWSGM .LT. USTCRB) THEN
         TAOCWS=0.5*(TAOCRB+TAOCWSE)
         USTCWS=SQRT(TAOCWS/RHOW)
      ENDIF

C FOR EQUILIBRIUM RIPPLES
      IF (USTCWSB .GE. USTCRB .AND. USTCWSB .LT. USTBF) THEN
C CHOICE A: USE (TAOCRB+TAOCWS+TAOCWSE)/3 FOR USTCWSB<USTBF
C         TAOCWS=0.333*(TAOCRB+TAOCWS+TAOCWSE)
C         USTCWS=SQRT(TAOCWS/RHOW)
C CHOICE B: USE (TAOCRB+TAOCWSE)/2 FOR USTCWSB<USTBF
         TAOCWS=0.5*(TAOCRB+TAOCWSE)
         USTCWS=SQRT(TAOCWS/RHOW)
      ENDIF

C FOR BREAK-OFF RIPPLES
      IF (USTCWSB .GE. USTBF .AND. USTCWSB .LT. USTUP) THEN
         TAOCWS=(1/(2+ALPHA))*(ALPHA*TAOCRB+TAOCWS+TAOCWSE)
         USTCWS=SQRT(TAOCWS/RHOW)
      ENDIF

C FOR UPPER-PLANE BED
      IF (USTCWSB .GE. USTUP) USTCWS=SQRT(TAOCWS/RHOW)
C -------------------------------------------

         S=TAOCWS/TAOCRB - 1.
         IF (S .LT. 0) S = 0.0
         IF(IOPT1.EQ.4)THEN
           FACTOR = DABS(S-LOG(1+CONST3*S)/CONST3)
           CONST2 = 1.
         ELSEIF(IOPT1.EQ.5)THEN
           FACTOR = S**1.5
         ELSE
           FACTOR = 1.
         ENDIF

         SED=CONST1*STEPC*FACTOR*USTCWS**CONST2
         PHIS=ATAN2(TAOCSY,TAOCWSX)
         GSXC=SED*COS(PHIS)
         GSYC=SED*SIN(PHIS)
         SEDXC=SEDXC+GSXC
         SEDYC=SEDYC+GSYC
 111  CONTINUE
      SEDXC=2*SEDXC
      SEDYC=2*SEDYC

C ===================================================================
C COMPUTE TRANSPORT VOLUME UNDER THE WAVE TROUGH

C IF NO TRANSPORT OCCURRED UNDER WAVE TROUGH, EXIT
      IF (TIMET .EQ. 0.) GO TO 333

      DO 222 I = 0, (NT-1)
         TAOCWSX=TAOCSX+0.5*TAOWS*(COS(W*(RLWRT+I*STEPT))
     @           +COS(W*(RLWRT+(I+1)*STEPT)))
         TAOCWS=SQRT(TAOCSY**2+TAOCWSX**2)
         TAOCWSE=(RPLCOEF**2)*TAOCWS

C -------------------------------------------
C CASE O: NO
C USING THE AVERAGE GM SHEAR STRESS
C         USTCWS=SQRT(TAOCWS/RHOW)
C -------------------------------------------
C -------------------------------------------
C CASE A: NO
C USING EFFECTIVE SHEAR STRESS
C         USTCWS=RPLCOEF*SQRT(TAOCWS/RHOW)
C -------------------------------------------
C -----------------------------------------
C CASE B: NO
C USING THE AVERAGED EFFECTIVE SHEAR STRESS 0.5(TAOCRB+TAOCWSE)
C         TAOCWS=0.5*(TAOCRB+TAOCWSE)
C         USTCWS=SQRT(TAOCWS/RHOW)
C -----------------------------------------
C -----------------------------------------
C CASE C: NO OR CASE E: NO
C USING THE EFFECTIVE SHEAR STRESS OF WIBERG-NELSON (1992)
C
C FOR CASE C, TAOCWSE=1.4TAOCWS
C         IF (USTCWSB .LT. USTBF) TAOCWS=1.4*TAOCWS
C         IF (USTCWSB .GE. USTBF .AND. USTCWSB .LT. USTUP) THEN
C            TAOCWS=(1+0.4*ALPHA)*TAOCWS
C         ENDIF
C         IF (USTCWSB .GE. USTUP) TAOCWS=TAOCWS
C
C FOR CASE E, TAOCWSE=1.65TAOCWS
C         IF (USTCWSB .LT. USTBF) TAOCWS=1.65*TAOCWS
C         IF (USTCWSB .GE. USTBF .AND. USTCWSB .LT. USTUP) THEN
C            TAOCWS=(1+0.65*ALPHA)*TAOCWS
C         ENDIF
C         IF (USTCWSB .GE. USTUP) TAOCWS=TAOCWS
C
C         USTCWS=SQRT(TAOCWS/RHOW)
C -------------------------------------------
C -------------------------------------------
C CASE D: YES
C USING THE NEW EFFECTIVE SHEAR STRESS

C FOR WEAK-TRANSPORT RIPPLES
      IF (USTCWSGM .LT. USTCRB) THEN
         TAOCWS=0.5*(TAOCRB+TAOCWSE)
         USTCWS=SQRT(TAOCWS/RHOW)
      ENDIF

C FOR EQUILIBRIUM RIPPLES
      IF (USTCWSB .GE. USTCRB .AND. USTCWSB .LT. USTBF) THEN
C CHOICE A: USE (TAOCRB+TAOCWS+TAOCWSE)/3 FOR USTCWSB<USTBF
C         TAOCWS=0.333*(TAOCRB+TAOCWS+TAOCWSE)
C         USTCWS=SQRT(TAOCWS/RHOW)
C CHOICE B: USE (TAOCRB+TAOCWSE)/2 FOR USTCWSB<USTBF
         TAOCWS=0.5*(TAOCRB+TAOCWSE)
         USTCWS=SQRT(TAOCWS/RHOW)
      ENDIF

C FOR BREAK-OFF RIPPLES
      IF (USTCWSB .GE. USTBF .AND. USTCWSB .LT. USTUP) THEN
         TAOCWS=(1/(2+ALPHA))*(ALPHA*TAOCRB+TAOCWS+TAOCWSE)
         USTCWS=SQRT(TAOCWS/RHOW)
      ENDIF

C FOR UPPER-PLANE BED
      IF (USTCWSB .GE. USTUP) USTCWS=SQRT(TAOCWS/RHOW)
C -------------------------------------------

         S=TAOCWS/TAOCRB - 1.
         IF (S .LT. 0) S = 0.0
         IF(IOPT1.EQ.4)THEN
           FACTOR = DABS(S-LOG(1+CONST3*S)/CONST3)
           CONST2 = 1.
         ELSEIF(IOPT1.EQ.5)THEN
           FACTOR = S**1.5
         ELSE
           FACTOR = 1.
         ENDIF

         SED=CONST1*STEPT*FACTOR*USTCWS**CONST2
         PHIS=ATAN2(TAOCSY,TAOCWSX)
         IF (PHIS .LT. 0) THEN
               GSXT=-SED*COS(PHIS)
               GSYT=-SED*SIN(PHIS)
         ELSE
               GSXT=SED*COS(PHIS)
               GSYT=SED*SIN(PHIS)
         ENDIF
         SEDXT=SEDXT+GSXT
         SEDYT=SEDYT+GSYT
 222  CONTINUE
      SEDXT=2*SEDXT
      SEDYT=2*SEDYT
C ===================================================================

 333  CONTINUE

C RETURN THE BURST-AVERAGED SHEAR VELOCITIES
      USTCS=USTCSGM
      USTWS=USTWSGM
      USTCWS=USTCWSGM

C COMPUTE THE DIRECTION OF THE TRANSPORT
      SEDX=(SEDXC+SEDXT)/PER
      SEDY=(SEDYC+SEDYT)/PER
      SED=SQRT(SEDX**2+SEDY**2)
      IF (SEDY .EQ. 0. .AND. SEDX .EQ. 0.) THEN
         SEDDIR = 0.
      ELSE
         PHIS=ATAN2(SEDY,SEDX)
         DIF=SIGN((PHI100-PHIS)*180./PII,CDIR-WDIR)
         CWDIF=ABS(CDIR-WDIR)
         IF(CWDIF .LE. 90.0) SEDDIR=CDIR-DIF
         IF (CWDIF .LE. 180.0 .AND. CWDIF .GT. 90.0) SEDDIR=CDIR+DIF
         IF (CWDIF .LE. 270.0 .AND. CWDIF .GT. 180.0) SEDDIR=CDIR-DIF
         IF (CWDIF .LE. 360.0 .AND. CWDIF .GT. 270.0) SEDDIR=CDIR+DIF
         IF (SEDDIR .LT. 0.0) SEDDIR=SEDDIR+360.0
         IF (SEDDIR .GE. 360.0) SEDDIR=SEDDIR-360.0
      ENDIF

      IF(USTCS .EQ. 0.) SEDDIR = WDIR

      RETURN
      END

